from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Iis
IISADMIN_EXTENSIONS_REG_KEYA: String = 'SOFTWARE\\Microsoft\\InetStp\\Extensions'
IISADMIN_EXTENSIONS_REG_KEYW: String = 'SOFTWARE\\Microsoft\\InetStp\\Extensions'
IISADMIN_EXTENSIONS_REG_KEY: String = 'SOFTWARE\\Microsoft\\InetStp\\Extensions'
IISADMIN_EXTENSIONS_CLSID_MD_KEYA: String = 'LM/IISADMIN/EXTENSIONS/DCOMCLSIDS'
IISADMIN_EXTENSIONS_CLSID_MD_KEYW: String = 'LM/IISADMIN/EXTENSIONS/DCOMCLSIDS'
IISADMIN_EXTENSIONS_CLSID_MD_KEY: String = 'LM/IISADMIN/EXTENSIONS/DCOMCLSIDS'
ADMINDATA_MAX_NAME_LEN: UInt32 = 256
CLSID_MSAdminBase_W: Guid = Guid('{a9e69610-b80d-11d0-b9b9-00a0c922e750}')
IMGCHG_SIZE: UInt32 = 1
IMGCHG_VIEW: UInt32 = 2
IMGCHG_COMPLETE: UInt32 = 4
IMGCHG_ANIMATE: UInt32 = 8
IMGCHG_MASK: UInt32 = 15
IMGLOAD_NOTLOADED: UInt32 = 1048576
IMGLOAD_LOADING: UInt32 = 2097152
IMGLOAD_STOPPED: UInt32 = 4194304
IMGLOAD_ERROR: UInt32 = 8388608
IMGLOAD_COMPLETE: UInt32 = 16777216
IMGLOAD_MASK: UInt32 = 32505856
IMGBITS_NONE: UInt32 = 33554432
IMGBITS_PARTIAL: UInt32 = 67108864
IMGBITS_TOTAL: UInt32 = 134217728
IMGBITS_MASK: UInt32 = 234881024
IMGANIM_ANIMATED: UInt32 = 268435456
IMGANIM_MASK: UInt32 = 268435456
IMGTRANS_OPAQUE: UInt32 = 536870912
IMGTRANS_MASK: UInt32 = 536870912
DWN_COLORMODE: UInt32 = 63
DWN_DOWNLOADONLY: UInt32 = 64
DWN_FORCEDITHER: UInt32 = 128
DWN_RAWIMAGE: UInt32 = 256
DWN_MIRRORIMAGE: UInt32 = 512
CLSID_IImgCtx: Guid = Guid('{3050f3d6-98b5-11cf-bb82-00aa00bdce0b}')
IIS_MD_LOCAL_MACHINE_PATH: String = 'LM'
IIS_MD_INSTANCE_ROOT: String = 'Root'
IIS_MD_ISAPI_FILTERS: String = '/Filters'
IIS_MD_SVC_INFO_PATH: String = 'Info'
IIS_MD_ADSI_SCHEMA_PATH_A: String = '/Schema'
IIS_MD_ADSI_SCHEMA_PATH_W: String = '/Schema'
IIS_MD_ADSI_METAID_BEGIN: UInt32 = 130000
IIS_MD_UT_SERVER: UInt32 = 1
IIS_MD_UT_FILE: UInt32 = 2
IIS_MD_UT_WAM: UInt32 = 100
ASP_MD_UT_APP: UInt32 = 101
IIS_MD_UT_END_RESERVED: UInt32 = 2000
IIS_MD_ID_BEGIN_RESERVED: UInt32 = 1
IIS_MD_ID_END_RESERVED: UInt32 = 32767
ASP_MD_ID_BEGIN_RESERVED: UInt32 = 28672
ASP_MD_ID_END_RESERVED: UInt32 = 29951
WAM_MD_ID_BEGIN_RESERVED: UInt32 = 29952
WAM_MD_ID_END_RESERVED: UInt32 = 32767
FP_MD_ID_BEGIN_RESERVED: UInt32 = 32768
FP_MD_ID_END_RESERVED: UInt32 = 36863
SMTP_MD_ID_BEGIN_RESERVED: UInt32 = 36864
SMTP_MD_ID_END_RESERVED: UInt32 = 40959
POP3_MD_ID_BEGIN_RESERVED: UInt32 = 40960
POP3_MD_ID_END_RESERVED: UInt32 = 45055
NNTP_MD_ID_BEGIN_RESERVED: UInt32 = 45056
NNTP_MD_ID_END_RESERVED: UInt32 = 49151
IMAP_MD_ID_BEGIN_RESERVED: UInt32 = 49152
IMAP_MD_ID_END_RESERVED: UInt32 = 53247
MSCS_MD_ID_BEGIN_RESERVED: UInt32 = 53248
MSCS_MD_ID_END_RESERVED: UInt32 = 57343
APPCTR_MD_ID_BEGIN_RESERVED: UInt32 = 57344
APPCTR_MD_ID_END_RESERVED: UInt32 = 61439
USER_MD_ID_BASE_RESERVED: UInt32 = 65535
IIS_MD_SERVER_BASE: UInt32 = 1000
MD_MAX_BANDWIDTH: UInt32 = 1000
MD_KEY_TYPE: UInt32 = 1002
MD_MAX_BANDWIDTH_BLOCKED: UInt32 = 1003
MD_SCHEMA_METAID: UInt32 = 1004
MD_SERVER_COMMAND: UInt32 = 1012
MD_CONNECTION_TIMEOUT: UInt32 = 1013
MD_MAX_CONNECTIONS: UInt32 = 1014
MD_SERVER_COMMENT: UInt32 = 1015
MD_SERVER_STATE: UInt32 = 1016
MD_SERVER_AUTOSTART: UInt32 = 1017
MD_SERVER_SIZE: UInt32 = 1018
MD_SERVER_LISTEN_BACKLOG: UInt32 = 1019
MD_SERVER_LISTEN_TIMEOUT: UInt32 = 1020
MD_DOWNLEVEL_ADMIN_INSTANCE: UInt32 = 1021
MD_LEVELS_TO_SCAN: UInt32 = 1022
MD_SERVER_BINDINGS: UInt32 = 1023
MD_MAX_ENDPOINT_CONNECTIONS: UInt32 = 1024
MD_SERVER_CONFIGURATION_INFO: UInt32 = 1027
MD_IISADMIN_EXTENSIONS: UInt32 = 1028
MD_DISABLE_SOCKET_POOLING: UInt32 = 1029
MD_METADATA_ID_REGISTRATION: UInt32 = 1030
IIS_MD_HTTP_BASE: UInt32 = 2000
MD_SECURE_BINDINGS: UInt32 = 2021
MD_BINDINGS: UInt32 = 2022
MD_ENABLEDPROTOCOLS: UInt32 = 2023
MD_FILTER_LOAD_ORDER: UInt32 = 2040
MD_FILTER_IMAGE_PATH: UInt32 = 2041
MD_FILTER_STATE: UInt32 = 2042
MD_FILTER_ENABLED: UInt32 = 2043
MD_FILTER_FLAGS: UInt32 = 2044
MD_FILTER_DESCRIPTION: UInt32 = 2045
MD_FILTER_ENABLE_CACHE: UInt32 = 2046
MD_ADV_NOTIFY_PWD_EXP_IN_DAYS: UInt32 = 2063
MD_ADV_CACHE_TTL: UInt32 = 2064
MD_NET_LOGON_WKS: UInt32 = 2065
MD_USE_HOST_NAME: UInt32 = 2066
MD_AUTH_CHANGE_FLAGS: UInt32 = 2068
MD_PROCESS_NTCR_IF_LOGGED_ON: UInt32 = 2070
MD_FRONTPAGE_WEB: UInt32 = 2072
MD_IN_PROCESS_ISAPI_APPS: UInt32 = 2073
MD_AUTH_CHANGE_URL: UInt32 = 2060
MD_AUTH_EXPIRED_URL: UInt32 = 2061
MD_AUTH_EXPIRED_UNSECUREURL: UInt32 = 2067
MD_ALLOW_PATH_INFO_FOR_SCRIPT_MAPPINGS: UInt32 = 2095
MD_APP_FRIENDLY_NAME: UInt32 = 2102
MD_APP_ROOT: UInt32 = 2103
MD_APP_ISOLATED: UInt32 = 2104
MD_APP_WAM_CLSID: UInt32 = 2105
MD_APP_PACKAGE_ID: UInt32 = 2106
MD_APP_PACKAGE_NAME: UInt32 = 2107
MD_APP_OOP_RECOVER_LIMIT: UInt32 = 2110
MD_APP_PERIODIC_RESTART_TIME: UInt32 = 2111
MD_APP_PERIODIC_RESTART_REQUESTS: UInt32 = 2112
MD_APP_PERIODIC_RESTART_SCHEDULE: UInt32 = 2113
MD_APP_SHUTDOWN_TIME_LIMIT: UInt32 = 2114
MD_ADMIN_INSTANCE: UInt32 = 2115
MD_NOT_DELETABLE: UInt32 = 2116
MD_APP_TRACE_URL_LIST: UInt32 = 2118
MD_CENTRAL_W3C_LOGGING_ENABLED: UInt32 = 2119
MD_CUSTOM_ERROR_DESC: UInt32 = 2120
MD_CAL_VC_PER_CONNECT: UInt32 = 2130
MD_CAL_AUTH_RESERVE_TIMEOUT: UInt32 = 2131
MD_CAL_SSL_RESERVE_TIMEOUT: UInt32 = 2132
MD_CAL_W3_ERROR: UInt32 = 2133
MD_CPU_CGI_ENABLED: UInt32 = 2140
MD_CPU_APP_ENABLED: UInt32 = 2141
MD_CPU_LIMITS_ENABLED: UInt32 = 2143
MD_CPU_RESET_INTERVAL: UInt32 = 2144
MD_CPU_LOGGING_INTERVAL: UInt32 = 2145
MD_CPU_LOGGING_OPTIONS: UInt32 = 2146
MD_CPU_CGI_LIMIT: UInt32 = 2148
MD_CPU_LIMIT_LOGEVENT: UInt32 = 2149
MD_CPU_LIMIT_PRIORITY: UInt32 = 2150
MD_CPU_LIMIT_PROCSTOP: UInt32 = 2151
MD_CPU_LIMIT_PAUSE: UInt32 = 2152
MD_SET_HOST_NAME: UInt32 = 2154
MD_CPU_DISABLE_ALL_LOGGING: UInt32 = 0
MD_CPU_ENABLE_ALL_PROC_LOGGING: UInt32 = 1
MD_CPU_ENABLE_CGI_LOGGING: UInt32 = 2
MD_CPU_ENABLE_APP_LOGGING: UInt32 = 4
MD_CPU_ENABLE_EVENT: UInt32 = 1
MD_CPU_ENABLE_PROC_TYPE: UInt32 = 2
MD_CPU_ENABLE_USER_TIME: UInt32 = 4
MD_CPU_ENABLE_KERNEL_TIME: UInt32 = 8
MD_CPU_ENABLE_PAGE_FAULTS: UInt32 = 16
MD_CPU_ENABLE_TOTAL_PROCS: UInt32 = 32
MD_CPU_ENABLE_ACTIVE_PROCS: UInt32 = 64
MD_CPU_ENABLE_TERMINATED_PROCS: UInt32 = 128
MD_CPU_ENABLE_LOGGING: UInt32 = 2147483648
MD_ISAPI_RESTRICTION_LIST: UInt32 = 2163
MD_CGI_RESTRICTION_LIST: UInt32 = 2164
MD_RESTRICTION_LIST_CUSTOM_DESC: UInt32 = 2165
MD_SECURITY_SETUP_REQUIRED: UInt32 = 2166
MD_APP_DEPENDENCIES: UInt32 = 2167
MD_WEB_SVC_EXT_RESTRICTION_LIST: UInt32 = 2168
MD_MD_SERVER_SS_AUTH_MAPPING: UInt32 = 2200
MD_CERT_NO_REVOC_CHECK: UInt32 = 1
MD_CERT_CACHE_RETRIEVAL_ONLY: UInt32 = 2
MD_CERT_CHECK_REVOCATION_FRESHNESS_TIME: UInt32 = 4
MD_CERT_NO_USAGE_CHECK: UInt32 = 65536
MD_HC_COMPRESSION_DIRECTORY: UInt32 = 2210
MD_HC_CACHE_CONTROL_HEADER: UInt32 = 2211
MD_HC_EXPIRES_HEADER: UInt32 = 2212
MD_HC_DO_DYNAMIC_COMPRESSION: UInt32 = 2213
MD_HC_DO_STATIC_COMPRESSION: UInt32 = 2214
MD_HC_DO_ON_DEMAND_COMPRESSION: UInt32 = 2215
MD_HC_DO_DISK_SPACE_LIMITING: UInt32 = 2216
MD_HC_NO_COMPRESSION_FOR_HTTP_10: UInt32 = 2217
MD_HC_NO_COMPRESSION_FOR_PROXIES: UInt32 = 2218
MD_HC_NO_COMPRESSION_FOR_RANGE: UInt32 = 2219
MD_HC_SEND_CACHE_HEADERS: UInt32 = 2220
MD_HC_MAX_DISK_SPACE_USAGE: UInt32 = 2221
MD_HC_IO_BUFFER_SIZE: UInt32 = 2222
MD_HC_COMPRESSION_BUFFER_SIZE: UInt32 = 2223
MD_HC_MAX_QUEUE_LENGTH: UInt32 = 2224
MD_HC_FILES_DELETED_PER_DISK_FREE: UInt32 = 2225
MD_HC_MIN_FILE_SIZE_FOR_COMP: UInt32 = 2226
MD_HC_COMPRESSION_DLL: UInt32 = 2237
MD_HC_FILE_EXTENSIONS: UInt32 = 2238
MD_HC_MIME_TYPE: UInt32 = 2239
MD_HC_PRIORITY: UInt32 = 2240
MD_HC_DYNAMIC_COMPRESSION_LEVEL: UInt32 = 2241
MD_HC_ON_DEMAND_COMP_LEVEL: UInt32 = 2242
MD_HC_CREATE_FLAGS: UInt32 = 2243
MD_HC_SCRIPT_FILE_EXTENSIONS: UInt32 = 2244
MD_HC_DO_NAMESPACE_DYNAMIC_COMPRESSION: UInt32 = 2255
MD_HC_DO_NAMESPACE_STATIC_COMPRESSION: UInt32 = 2256
MD_WIN32_ERROR: UInt32 = 1099
IIS_MD_VR_BASE: UInt32 = 3000
MD_VR_PATH: UInt32 = 3001
MD_VR_USERNAME: UInt32 = 3002
MD_VR_PASSWORD: UInt32 = 3003
MD_VR_PASSTHROUGH: UInt32 = 3006
MD_VR_NO_CACHE: UInt32 = 3007
MD_VR_IGNORE_TRANSLATE: UInt32 = 3008
IIS_MD_LOG_BASE: UInt32 = 4000
MD_LOG_TYPE: UInt32 = 4000
MD_LOGFILE_DIRECTORY: UInt32 = 4001
MD_LOG_UNUSED1: UInt32 = 4002
MD_LOGFILE_PERIOD: UInt32 = 4003
MD_LOGFILE_TRUNCATE_SIZE: UInt32 = 4004
MD_LOG_PLUGIN_MOD_ID: UInt32 = 4005
MD_LOG_PLUGIN_UI_ID: UInt32 = 4006
MD_LOGSQL_DATA_SOURCES: UInt32 = 4007
MD_LOGSQL_TABLE_NAME: UInt32 = 4008
MD_LOGSQL_USER_NAME: UInt32 = 4009
MD_LOGSQL_PASSWORD: UInt32 = 4010
MD_LOG_PLUGIN_ORDER: UInt32 = 4011
MD_LOG_PLUGINS_AVAILABLE: UInt32 = 4012
MD_LOGEXT_FIELD_MASK: UInt32 = 4013
MD_LOGEXT_FIELD_MASK2: UInt32 = 4014
MD_LOGFILE_LOCALTIME_ROLLOVER: UInt32 = 4015
IIS_MD_LOG_LAST: UInt32 = 4015
MD_GLOBAL_BINARY_LOGGING_ENABLED: UInt32 = 4016
MD_LOG_TYPE_DISABLED: UInt32 = 0
MD_LOG_TYPE_ENABLED: UInt32 = 1
MD_LOGFILE_PERIOD_NONE: UInt32 = 0
MD_LOGFILE_PERIOD_MAXSIZE: UInt32 = 0
MD_LOGFILE_PERIOD_DAILY: UInt32 = 1
MD_LOGFILE_PERIOD_WEEKLY: UInt32 = 2
MD_LOGFILE_PERIOD_MONTHLY: UInt32 = 3
MD_LOGFILE_PERIOD_HOURLY: UInt32 = 4
MD_EXTLOG_DATE: UInt32 = 1
MD_EXTLOG_TIME: UInt32 = 2
MD_EXTLOG_CLIENT_IP: UInt32 = 4
MD_EXTLOG_USERNAME: UInt32 = 8
MD_EXTLOG_SITE_NAME: UInt32 = 16
MD_EXTLOG_COMPUTER_NAME: UInt32 = 32
MD_EXTLOG_SERVER_IP: UInt32 = 64
MD_EXTLOG_METHOD: UInt32 = 128
MD_EXTLOG_URI_STEM: UInt32 = 256
MD_EXTLOG_URI_QUERY: UInt32 = 512
MD_EXTLOG_HTTP_STATUS: UInt32 = 1024
MD_EXTLOG_WIN32_STATUS: UInt32 = 2048
MD_EXTLOG_BYTES_SENT: UInt32 = 4096
MD_EXTLOG_BYTES_RECV: UInt32 = 8192
MD_EXTLOG_TIME_TAKEN: UInt32 = 16384
MD_EXTLOG_SERVER_PORT: UInt32 = 32768
MD_EXTLOG_USER_AGENT: UInt32 = 65536
MD_EXTLOG_COOKIE: UInt32 = 131072
MD_EXTLOG_REFERER: UInt32 = 262144
MD_EXTLOG_PROTOCOL_VERSION: UInt32 = 524288
MD_EXTLOG_HOST: UInt32 = 1048576
MD_EXTLOG_HTTP_SUB_STATUS: UInt32 = 2097152
IIS_MD_LOGCUSTOM_BASE: UInt32 = 4500
MD_LOGCUSTOM_PROPERTY_NAME: UInt32 = 4501
MD_LOGCUSTOM_PROPERTY_HEADER: UInt32 = 4502
MD_LOGCUSTOM_PROPERTY_ID: UInt32 = 4503
MD_LOGCUSTOM_PROPERTY_MASK: UInt32 = 4504
MD_LOGCUSTOM_PROPERTY_DATATYPE: UInt32 = 4505
MD_LOGCUSTOM_SERVICES_STRING: UInt32 = 4506
MD_CPU_LOGGING_MASK: UInt32 = 4507
MD_LOGCUSTOM_PROPERTY_NODE_ID: UInt32 = 4508
IIS_MD_LOGCUSTOM_LAST: UInt32 = 4508
MD_LOGCUSTOM_DATATYPE_INT: UInt32 = 0
MD_LOGCUSTOM_DATATYPE_UINT: UInt32 = 1
MD_LOGCUSTOM_DATATYPE_LONG: UInt32 = 2
MD_LOGCUSTOM_DATATYPE_ULONG: UInt32 = 3
MD_LOGCUSTOM_DATATYPE_FLOAT: UInt32 = 4
MD_LOGCUSTOM_DATATYPE_DOUBLE: UInt32 = 5
MD_LOGCUSTOM_DATATYPE_LPSTR: UInt32 = 6
MD_LOGCUSTOM_DATATYPE_LPWSTR: UInt32 = 7
MD_NOTIFY_SECURE_PORT: UInt32 = 1
MD_NOTIFY_NONSECURE_PORT: UInt32 = 2
MD_NOTIFY_READ_RAW_DATA: UInt32 = 32768
MD_NOTIFY_PREPROC_HEADERS: UInt32 = 16384
MD_NOTIFY_AUTHENTICATION: UInt32 = 8192
MD_NOTIFY_URL_MAP: UInt32 = 4096
MD_NOTIFY_ACCESS_DENIED: UInt32 = 2048
MD_NOTIFY_SEND_RESPONSE: UInt32 = 64
MD_NOTIFY_SEND_RAW_DATA: UInt32 = 1024
MD_NOTIFY_LOG: UInt32 = 512
MD_NOTIFY_END_OF_REQUEST: UInt32 = 128
MD_NOTIFY_END_OF_NET_SESSION: UInt32 = 256
MD_NOTIFY_AUTH_COMPLETE: UInt32 = 67108864
MD_NOTIFY_ORDER_HIGH: UInt32 = 524288
MD_NOTIFY_ORDER_MEDIUM: UInt32 = 262144
MD_NOTIFY_ORDER_LOW: UInt32 = 131072
MD_NOTIFY_ORDER_DEFAULT: UInt32 = 131072
IIS_MD_FTP_BASE: UInt32 = 5000
MD_EXIT_MESSAGE: UInt32 = 5001
MD_GREETING_MESSAGE: UInt32 = 5002
MD_MAX_CLIENTS_MESSAGE: UInt32 = 5003
MD_MSDOS_DIR_OUTPUT: UInt32 = 5004
MD_ALLOW_ANONYMOUS: UInt32 = 5005
MD_ANONYMOUS_ONLY: UInt32 = 5006
MD_LOG_ANONYMOUS: UInt32 = 5007
MD_LOG_NONANONYMOUS: UInt32 = 5008
MD_ALLOW_REPLACE_ON_RENAME: UInt32 = 5009
MD_SHOW_4_DIGIT_YEAR: UInt32 = 5010
MD_BANNER_MESSAGE: UInt32 = 5011
MD_USER_ISOLATION: UInt32 = 5012
MD_FTP_LOG_IN_UTF_8: UInt32 = 5013
MD_AD_CONNECTIONS_USERNAME: UInt32 = 5014
MD_AD_CONNECTIONS_PASSWORD: UInt32 = 5015
MD_PASSIVE_PORT_RANGE: UInt32 = 5016
MD_SUPPRESS_DEFAULT_BANNER: UInt32 = 5017
MD_FTP_PASV_RESPONSE_IP: UInt32 = 5018
MD_FTP_KEEP_PARTIAL_UPLOADS: UInt32 = 5019
MD_FTP_UTF8_FILE_NAMES: UInt32 = 5020
MD_FTPS_SECURE_CONTROL_CHANNEL: UInt32 = 5050
MD_FTPS_SECURE_DATA_CHANNEL: UInt32 = 5051
MD_FTPS_SECURE_ANONYMOUS: UInt32 = 5052
MD_FTPS_128_BITS: UInt32 = 5053
MD_FTPS_ALLOW_CCC: UInt32 = 5054
IIS_MD_SSL_BASE: UInt32 = 5500
MD_SSL_PUBLIC_KEY: UInt32 = 5500
MD_SSL_PRIVATE_KEY: UInt32 = 5501
MD_SSL_KEY_PASSWORD: UInt32 = 5502
MD_SSL_KEY_REQUEST: UInt32 = 5503
MD_SSL_USE_DS_MAPPER: UInt32 = 5519
MD_SSL_ALWAYS_NEGO_CLIENT_CERT: UInt32 = 5521
IIS_MD_FILE_PROP_BASE: UInt32 = 6000
MD_AUTHORIZATION: UInt32 = 6000
MD_REALM: UInt32 = 6001
MD_HTTP_EXPIRES: UInt32 = 6002
MD_HTTP_PICS: UInt32 = 6003
MD_HTTP_CUSTOM: UInt32 = 6004
MD_DIRECTORY_BROWSING: UInt32 = 6005
MD_DEFAULT_LOAD_FILE: UInt32 = 6006
MD_CUSTOM_ERROR: UInt32 = 6008
MD_FOOTER_DOCUMENT: UInt32 = 6009
MD_FOOTER_ENABLED: UInt32 = 6010
MD_HTTP_REDIRECT: UInt32 = 6011
MD_DEFAULT_LOGON_DOMAIN: UInt32 = 6012
MD_LOGON_METHOD: UInt32 = 6013
MD_SCRIPT_MAPS: UInt32 = 6014
MD_MIME_MAP: UInt32 = 6015
MD_ACCESS_PERM: UInt32 = 6016
MD_IP_SEC: UInt32 = 6019
MD_ANONYMOUS_USER_NAME: UInt32 = 6020
MD_ANONYMOUS_PWD: UInt32 = 6021
MD_ANONYMOUS_USE_SUBAUTH: UInt32 = 6022
MD_DONT_LOG: UInt32 = 6023
MD_ADMIN_ACL: UInt32 = 6027
MD_SSI_EXEC_DISABLED: UInt32 = 6028
MD_DO_REVERSE_DNS: UInt32 = 6029
MD_SSL_ACCESS_PERM: UInt32 = 6030
MD_AUTHORIZATION_PERSISTENCE: UInt32 = 6031
MD_NTAUTHENTICATION_PROVIDERS: UInt32 = 6032
MD_SCRIPT_TIMEOUT: UInt32 = 6033
MD_CACHE_EXTENSIONS: UInt32 = 6034
MD_CREATE_PROCESS_AS_USER: UInt32 = 6035
MD_CREATE_PROC_NEW_CONSOLE: UInt32 = 6036
MD_POOL_IDC_TIMEOUT: UInt32 = 6037
MD_ALLOW_KEEPALIVES: UInt32 = 6038
MD_IS_CONTENT_INDEXED: UInt32 = 6039
MD_CC_NO_CACHE: UInt32 = 6041
MD_CC_MAX_AGE: UInt32 = 6042
MD_CC_OTHER: UInt32 = 6043
MD_REDIRECT_HEADERS: UInt32 = 6044
MD_UPLOAD_READAHEAD_SIZE: UInt32 = 6045
MD_PUT_READ_SIZE: UInt32 = 6046
MD_USE_DIGEST_SSP: UInt32 = 6047
MD_ENABLE_URL_AUTHORIZATION: UInt32 = 6048
MD_URL_AUTHORIZATION_STORE_NAME: UInt32 = 6049
MD_URL_AUTHORIZATION_SCOPE_NAME: UInt32 = 6050
MD_MAX_REQUEST_ENTITY_ALLOWED: UInt32 = 6051
MD_PASSPORT_REQUIRE_AD_MAPPING: UInt32 = 6052
MD_URL_AUTHORIZATION_IMPERSONATION_LEVEL: UInt32 = 6053
MD_HTTP_FORWARDER_CUSTOM: UInt32 = 6054
MD_CUSTOM_DEPLOYMENT_DATA: UInt32 = 6055
MD_HTTPERRORS_EXISTING_RESPONSE: UInt32 = 6056
ASP_MD_SERVER_BASE: UInt32 = 7000
MD_ASP_BUFFERINGON: UInt32 = 7000
MD_ASP_LOGERRORREQUESTS: UInt32 = 7001
MD_ASP_SCRIPTERRORSSENTTOBROWSER: UInt32 = 7002
MD_ASP_SCRIPTERRORMESSAGE: UInt32 = 7003
MD_ASP_SCRIPTFILECACHESIZE: UInt32 = 7004
MD_ASP_SCRIPTENGINECACHEMAX: UInt32 = 7005
MD_ASP_SCRIPTTIMEOUT: UInt32 = 7006
MD_ASP_SESSIONTIMEOUT: UInt32 = 7007
MD_ASP_ENABLEPARENTPATHS: UInt32 = 7008
MD_ASP_MEMFREEFACTOR: UInt32 = 7009
MD_ASP_MINUSEDBLOCKS: UInt32 = 7010
MD_ASP_ALLOWSESSIONSTATE: UInt32 = 7011
MD_ASP_SCRIPTLANGUAGE: UInt32 = 7012
MD_ASP_QUEUETIMEOUT: UInt32 = 7013
MD_ASP_ALLOWOUTOFPROCCOMPONENTS: UInt32 = 7014
MD_ASP_ALLOWOUTOFPROCCMPNTS: UInt32 = 7014
MD_ASP_EXCEPTIONCATCHENABLE: UInt32 = 7015
MD_ASP_CODEPAGE: UInt32 = 7016
MD_ASP_SCRIPTLANGUAGELIST: UInt32 = 7017
MD_ASP_ENABLESERVERDEBUG: UInt32 = 7018
MD_ASP_ENABLECLIENTDEBUG: UInt32 = 7019
MD_ASP_TRACKTHREADINGMODEL: UInt32 = 7020
MD_ASP_ENABLEASPHTMLFALLBACK: UInt32 = 7021
MD_ASP_ENABLECHUNKEDENCODING: UInt32 = 7022
MD_ASP_ENABLETYPELIBCACHE: UInt32 = 7023
MD_ASP_ERRORSTONTLOG: UInt32 = 7024
MD_ASP_PROCESSORTHREADMAX: UInt32 = 7025
MD_ASP_REQEUSTQUEUEMAX: UInt32 = 7026
MD_ASP_ENABLEAPPLICATIONRESTART: UInt32 = 7027
MD_ASP_QUEUECONNECTIONTESTTIME: UInt32 = 7028
MD_ASP_SESSIONMAX: UInt32 = 7029
MD_ASP_THREADGATEENABLED: UInt32 = 7030
MD_ASP_THREADGATETIMESLICE: UInt32 = 7031
MD_ASP_THREADGATESLEEPDELAY: UInt32 = 7032
MD_ASP_THREADGATESLEEPMAX: UInt32 = 7033
MD_ASP_THREADGATELOADLOW: UInt32 = 7034
MD_ASP_THREADGATELOADHIGH: UInt32 = 7035
MD_ASP_DISKTEMPLATECACHEDIRECTORY: UInt32 = 7036
MD_ASP_MAXDISKTEMPLATECACHEFILES: UInt32 = 7040
MD_ASP_EXECUTEINMTA: UInt32 = 7041
MD_ASP_LCID: UInt32 = 7042
MD_ASP_KEEPSESSIONIDSECURE: UInt32 = 7043
MD_ASP_SERVICE_FLAGS: UInt32 = 7044
MD_ASP_SERVICE_FLAG_TRACKER: UInt32 = 7045
MD_ASP_SERVICE_FLAG_FUSION: UInt32 = 7046
MD_ASP_SERVICE_FLAG_PARTITIONS: UInt32 = 7047
MD_ASP_SERVICE_PARTITION_ID: UInt32 = 7048
MD_ASP_SERVICE_SXS_NAME: UInt32 = 7049
MD_ASP_SERVICE_ENABLE_TRACKER: UInt32 = 1
MD_ASP_SERVICE_ENABLE_SXS: UInt32 = 2
MD_ASP_SERVICE_USE_PARTITION: UInt32 = 4
MD_ASP_CALCLINENUMBER: UInt32 = 7050
MD_ASP_RUN_ONEND_ANON: UInt32 = 7051
MD_ASP_BUFFER_LIMIT: UInt32 = 7052
MD_ASP_MAX_REQUEST_ENTITY_ALLOWED: UInt32 = 7053
MD_ASP_MAXREQUESTENTITY: UInt32 = 7053
MD_ASP_ID_LAST: UInt32 = 7053
WAM_MD_SERVER_BASE: UInt32 = 7500
MD_WAM_USER_NAME: UInt32 = 7501
MD_WAM_PWD: UInt32 = 7502
WEBDAV_MD_SERVER_BASE: UInt32 = 8500
MD_WEBDAV_MAX_ATTRIBUTES_PER_ELEMENT: UInt32 = 8501
IIS_MD_APPPOOL_BASE: UInt32 = 9000
MD_APPPOOL_PERIODIC_RESTART_TIME: UInt32 = 9001
MD_APPPOOL_PERIODIC_RESTART_REQUEST_COUNT: UInt32 = 9002
MD_APPPOOL_MAX_PROCESS_COUNT: UInt32 = 9003
MD_APPPOOL_PINGING_ENABLED: UInt32 = 9004
MD_APPPOOL_IDLE_TIMEOUT: UInt32 = 9005
MD_APPPOOL_RAPID_FAIL_PROTECTION_ENABLED: UInt32 = 9006
MD_APPPOOL_SMP_AFFINITIZED: UInt32 = 9007
MD_APPPOOL_SMP_AFFINITIZED_PROCESSOR_MASK: UInt32 = 9008
MD_APPPOOL_ORPHAN_PROCESSES_FOR_DEBUGGING: UInt32 = 9009
MD_APPPOOL_STARTUP_TIMELIMIT: UInt32 = 9011
MD_APPPOOL_SHUTDOWN_TIMELIMIT: UInt32 = 9012
MD_APPPOOL_PING_INTERVAL: UInt32 = 9013
MD_APPPOOL_PING_RESPONSE_TIMELIMIT: UInt32 = 9014
MD_APPPOOL_DISALLOW_OVERLAPPING_ROTATION: UInt32 = 9015
MD_APPPOOL_UL_APPPOOL_QUEUE_LENGTH: UInt32 = 9017
MD_APPPOOL_DISALLOW_ROTATION_ON_CONFIG_CHANGE: UInt32 = 9018
MD_APPPOOL_PERIODIC_RESTART_SCHEDULE: UInt32 = 9020
MD_APPPOOL_IDENTITY_TYPE: UInt32 = 9021
MD_CPU_ACTION: UInt32 = 9022
MD_CPU_LIMIT: UInt32 = 9023
MD_APPPOOL_PERIODIC_RESTART_MEMORY: UInt32 = 9024
MD_APPPOOL_COMMAND: UInt32 = 9026
MD_APPPOOL_STATE: UInt32 = 9027
MD_APPPOOL_AUTO_START: UInt32 = 9028
MD_RAPID_FAIL_PROTECTION_INTERVAL: UInt32 = 9029
MD_RAPID_FAIL_PROTECTION_MAX_CRASHES: UInt32 = 9030
MD_APPPOOL_ORPHAN_ACTION_EXE: UInt32 = 9031
MD_APPPOOL_ORPHAN_ACTION_PARAMS: UInt32 = 9032
MB_DONT_IMPERSONATE: UInt32 = 9033
MD_LOAD_BALANCER_CAPABILITIES: UInt32 = 9034
MD_APPPOOL_AUTO_SHUTDOWN_EXE: UInt32 = 9035
MD_APPPOOL_AUTO_SHUTDOWN_PARAMS: UInt32 = 9036
MD_APP_POOL_LOG_EVENT_ON_RECYCLE: UInt32 = 9037
MD_APPPOOL_PERIODIC_RESTART_PRIVATE_MEMORY: UInt32 = 9038
MD_APPPOOL_MANAGED_RUNTIME_VERSION: UInt32 = 9039
MD_APPPOOL_32_BIT_APP_ON_WIN64: UInt32 = 9040
MD_APPPOOL_MANAGED_PIPELINE_MODE: UInt32 = 9041
MD_APP_POOL_LOG_EVENT_ON_PROCESSMODEL: UInt32 = 9042
MD_APPPOOL_EMULATION_ON_WINARM64: UInt32 = 9043
MD_APP_POOL_PROCESSMODEL_IDLE_TIMEOUT: UInt32 = 1
MD_APP_POOL_RECYCLE_TIME: UInt32 = 1
MD_APP_POOL_RECYCLE_REQUESTS: UInt32 = 2
MD_APP_POOL_RECYCLE_SCHEDULE: UInt32 = 4
MD_APP_POOL_RECYCLE_MEMORY: UInt32 = 8
MD_APP_POOL_RECYCLE_ISAPI_UNHEALTHY: UInt32 = 16
MD_APP_POOL_RECYCLE_ON_DEMAND: UInt32 = 32
MD_APP_POOL_RECYCLE_CONFIG_CHANGE: UInt32 = 64
MD_APP_POOL_RECYCLE_PRIVATE_MEMORY: UInt32 = 128
MD_CPU_NO_ACTION: UInt32 = 0
MD_CPU_KILL_W3WP: UInt32 = 1
MD_CPU_TRACE: UInt32 = 2
MD_CPU_THROTTLE: UInt32 = 3
MD_APPPOOL_COMMAND_START: UInt32 = 1
MD_APPPOOL_COMMAND_STOP: UInt32 = 2
MD_APPPOOL_STATE_STARTING: UInt32 = 1
MD_APPPOOL_STATE_STARTED: UInt32 = 2
MD_APPPOOL_STATE_STOPPING: UInt32 = 3
MD_APPPOOL_STATE_STOPPED: UInt32 = 4
MD_APPPOOL_IDENTITY_TYPE_LOCALSYSTEM: UInt32 = 0
MD_APPPOOL_IDENTITY_TYPE_LOCALSERVICE: UInt32 = 1
MD_APPPOOL_IDENTITY_TYPE_NETWORKSERVICE: UInt32 = 2
MD_APPPOOL_IDENTITY_TYPE_SPECIFICUSER: UInt32 = 3
MD_LOAD_BALANCER_CAPABILITIES_BASIC: UInt32 = 1
MD_LOAD_BALANCER_CAPABILITIES_SOPHISTICATED: UInt32 = 2
IIS_MD_APP_BASE: UInt32 = 9100
MD_APP_APPPOOL_ID: UInt32 = 9101
MD_APP_ALLOW_TRANSIENT_REGISTRATION: UInt32 = 9102
MD_APP_AUTO_START: UInt32 = 9103
MD_APPPOOL_PERIODIC_RESTART_CONNECTIONS: UInt32 = 9104
MD_APPPOOL_APPPOOL_ID: UInt32 = 9201
MD_APPPOOL_ALLOW_TRANSIENT_REGISTRATION: UInt32 = 9202
IIS_MD_GLOBAL_BASE: UInt32 = 9200
MD_MAX_GLOBAL_BANDWIDTH: UInt32 = 9201
MD_MAX_GLOBAL_CONNECTIONS: UInt32 = 9202
MD_GLOBAL_STANDARD_APP_MODE_ENABLED: UInt32 = 9203
MD_HEADER_WAIT_TIMEOUT: UInt32 = 9204
MD_MIN_FILE_BYTES_PER_SEC: UInt32 = 9205
MD_GLOBAL_LOG_IN_UTF_8: UInt32 = 9206
MD_DEMAND_START_THRESHOLD: UInt32 = 9207
MD_GLOBAL_SESSIONKEY: UInt32 = 9999
MD_ROOT_ENABLE_EDIT_WHILE_RUNNING: UInt32 = 9998
MD_GLOBAL_CHANGE_NUMBER: UInt32 = 9997
MD_ROOT_ENABLE_HISTORY: UInt32 = 9996
MD_ROOT_MAX_HISTORY_FILES: UInt32 = 9995
MD_GLOBAL_EDIT_WHILE_RUNNING_MAJOR_VERSION_NUMBER: UInt32 = 9994
MD_GLOBAL_EDIT_WHILE_RUNNING_MINOR_VERSION_NUMBER: UInt32 = 9993
MD_GLOBAL_XMLSCHEMATIMESTAMP: UInt32 = 9992
MD_GLOBAL_BINSCHEMATIMESTAMP: UInt32 = 9991
MD_COMMENTS: UInt32 = 9990
MD_LOCATION: UInt32 = 9989
MD_MAX_ERROR_FILES: UInt32 = 9988
MD_STOP_LISTENING: UInt32 = 9987
MD_AUTH_ANONYMOUS: UInt32 = 1
MD_AUTH_BASIC: UInt32 = 2
MD_AUTH_NT: UInt32 = 4
MD_AUTH_MD5: UInt32 = 16
MD_AUTH_PASSPORT: UInt32 = 64
MD_AUTH_SINGLEREQUEST: UInt32 = 64
MD_AUTH_SINGLEREQUESTIFPROXY: UInt32 = 128
MD_AUTH_SINGLEREQUESTALWAYSIFPROXY: UInt32 = 256
MD_ACCESS_READ: UInt32 = 1
MD_ACCESS_WRITE: UInt32 = 2
MD_ACCESS_EXECUTE: UInt32 = 4
MD_ACCESS_SOURCE: UInt32 = 16
MD_ACCESS_SCRIPT: UInt32 = 512
MD_ACCESS_NO_REMOTE_WRITE: UInt32 = 1024
MD_ACCESS_NO_REMOTE_READ: UInt32 = 4096
MD_ACCESS_NO_REMOTE_EXECUTE: UInt32 = 8192
MD_ACCESS_NO_REMOTE_SCRIPT: UInt32 = 16384
MD_ACCESS_NO_PHYSICAL_DIR: UInt32 = 32768
MD_ACCESS_SSL: UInt32 = 8
MD_ACCESS_NEGO_CERT: UInt32 = 32
MD_ACCESS_REQUIRE_CERT: UInt32 = 64
MD_ACCESS_MAP_CERT: UInt32 = 128
MD_ACCESS_SSL128: UInt32 = 256
MD_ACCESS_MASK: UInt32 = 65535
MD_DIRBROW_SHOW_DATE: UInt32 = 2
MD_DIRBROW_SHOW_TIME: UInt32 = 4
MD_DIRBROW_SHOW_SIZE: UInt32 = 8
MD_DIRBROW_SHOW_EXTENSION: UInt32 = 16
MD_DIRBROW_LONG_DATE: UInt32 = 32
MD_DIRBROW_ENABLED: UInt32 = 2147483648
MD_DIRBROW_LOADDEFAULT: UInt32 = 1073741824
MD_LOGON_INTERACTIVE: UInt32 = 0
MD_LOGON_BATCH: UInt32 = 1
MD_LOGON_NETWORK: UInt32 = 2
MD_LOGON_NETWORK_CLEARTEXT: UInt32 = 3
MD_PASSPORT_NO_MAPPING: UInt32 = 0
MD_PASSPORT_TRY_MAPPING: UInt32 = 1
MD_PASSPORT_NEED_MAPPING: UInt32 = 2
MD_NOTIFEXAUTH_NTLMSSL: UInt32 = 1
MD_FILTER_STATE_LOADED: UInt32 = 1
MD_FILTER_STATE_UNLOADED: UInt32 = 4
MD_SERVER_STATE_STARTING: UInt32 = 1
MD_SERVER_STATE_STARTED: UInt32 = 2
MD_SERVER_STATE_STOPPING: UInt32 = 3
MD_SERVER_STATE_STOPPED: UInt32 = 4
MD_SERVER_STATE_PAUSING: UInt32 = 5
MD_SERVER_STATE_PAUSED: UInt32 = 6
MD_SERVER_STATE_CONTINUING: UInt32 = 7
MD_SERVER_COMMAND_START: UInt32 = 1
MD_SERVER_COMMAND_STOP: UInt32 = 2
MD_SERVER_COMMAND_PAUSE: UInt32 = 3
MD_SERVER_COMMAND_CONTINUE: UInt32 = 4
MD_SERVER_SIZE_SMALL: UInt32 = 0
MD_SERVER_SIZE_MEDIUM: UInt32 = 1
MD_SERVER_SIZE_LARGE: UInt32 = 2
MD_SERVER_CONFIG_SSL_40: UInt32 = 1
MD_SERVER_CONFIG_SSL_128: UInt32 = 2
MD_SERVER_CONFIG_ALLOW_ENCRYPT: UInt32 = 4
MD_SERVER_CONFIG_AUTO_PW_SYNC: UInt32 = 8
MD_SCRIPTMAPFLAG_SCRIPT: UInt32 = 1
MD_SCRIPTMAPFLAG_CHECK_PATH_INFO: UInt32 = 4
MD_SCRIPTMAPFLAG_ALLOWED_ON_READ_DIR: UInt32 = 1
MD_AUTH_CHANGE_UNSECURE: UInt32 = 1
MD_AUTH_CHANGE_DISABLE: UInt32 = 2
MD_AUTH_ADVNOTIFY_DISABLE: UInt32 = 4
MD_NETLOGON_WKS_NONE: UInt32 = 0
MD_NETLOGON_WKS_IP: UInt32 = 1
MD_NETLOGON_WKS_DNS: UInt32 = 2
MD_ERROR_SUB400_INVALID_DESTINATION: UInt32 = 1
MD_ERROR_SUB400_INVALID_DEPTH: UInt32 = 2
MD_ERROR_SUB400_INVALID_IF: UInt32 = 3
MD_ERROR_SUB400_INVALID_OVERWRITE: UInt32 = 4
MD_ERROR_SUB400_INVALID_TRANSLATE: UInt32 = 5
MD_ERROR_SUB400_INVALID_REQUEST_BODY: UInt32 = 6
MD_ERROR_SUB400_INVALID_CONTENT_LENGTH: UInt32 = 7
MD_ERROR_SUB400_INVALID_TIMEOUT: UInt32 = 8
MD_ERROR_SUB400_INVALID_LOCK_TOKEN: UInt32 = 9
MD_ERROR_SUB400_INVALID_XFF_HEADER: UInt32 = 10
MD_ERROR_SUB400_INVALID_WEBSOCKET_REQUEST: UInt32 = 11
MD_ERROR_SUB401_LOGON: UInt32 = 1
MD_ERROR_SUB401_LOGON_CONFIG: UInt32 = 2
MD_ERROR_SUB401_LOGON_ACL: UInt32 = 3
MD_ERROR_SUB401_FILTER: UInt32 = 4
MD_ERROR_SUB401_APPLICATION: UInt32 = 5
MD_ERROR_SUB401_URLAUTH_POLICY: UInt32 = 7
MD_ERROR_SUB403_EXECUTE_ACCESS_DENIED: UInt32 = 1
MD_ERROR_SUB403_READ_ACCESS_DENIED: UInt32 = 2
MD_ERROR_SUB403_WRITE_ACCESS_DENIED: UInt32 = 3
MD_ERROR_SUB403_SSL_REQUIRED: UInt32 = 4
MD_ERROR_SUB403_SSL128_REQUIRED: UInt32 = 5
MD_ERROR_SUB403_ADDR_REJECT: UInt32 = 6
MD_ERROR_SUB403_CERT_REQUIRED: UInt32 = 7
MD_ERROR_SUB403_SITE_ACCESS_DENIED: UInt32 = 8
MD_ERROR_SUB403_TOO_MANY_USERS: UInt32 = 9
MD_ERROR_SUB403_INVALID_CNFG: UInt32 = 10
MD_ERROR_SUB403_PWD_CHANGE: UInt32 = 11
MD_ERROR_SUB403_MAPPER_DENY_ACCESS: UInt32 = 12
MD_ERROR_SUB403_CERT_REVOKED: UInt32 = 13
MD_ERROR_SUB403_DIR_LIST_DENIED: UInt32 = 14
MD_ERROR_SUB403_CAL_EXCEEDED: UInt32 = 15
MD_ERROR_SUB403_CERT_BAD: UInt32 = 16
MD_ERROR_SUB403_CERT_TIME_INVALID: UInt32 = 17
MD_ERROR_SUB403_APPPOOL_DENIED: UInt32 = 18
MD_ERROR_SUB403_INSUFFICIENT_PRIVILEGE_FOR_CGI: UInt32 = 19
MD_ERROR_SUB403_PASSPORT_LOGIN_FAILURE: UInt32 = 20
MD_ERROR_SUB403_SOURCE_ACCESS_DENIED: UInt32 = 21
MD_ERROR_SUB403_INFINITE_DEPTH_DENIED: UInt32 = 22
MD_ERROR_SUB403_LOCK_TOKEN_REQUIRED: UInt32 = 23
MD_ERROR_SUB403_VALIDATION_FAILURE: UInt32 = 24
MD_ERROR_SUB404_SITE_NOT_FOUND: UInt32 = 1
MD_ERROR_SUB404_DENIED_BY_POLICY: UInt32 = 2
MD_ERROR_SUB404_DENIED_BY_MIMEMAP: UInt32 = 3
MD_ERROR_SUB404_NO_HANDLER: UInt32 = 4
MD_ERROR_SUB404_URL_SEQUENCE_DENIED: UInt32 = 5
MD_ERROR_SUB404_VERB_DENIED: UInt32 = 6
MD_ERROR_SUB404_FILE_EXTENSION_DENIED: UInt32 = 7
MD_ERROR_SUB404_HIDDEN_SEGMENT: UInt32 = 8
MD_ERROR_SUB404_FILE_ATTRIBUTE_HIDDEN: UInt32 = 9
MD_ERROR_SUB404_URL_DOUBLE_ESCAPED: UInt32 = 11
MD_ERROR_SUB404_URL_HAS_HIGH_BIT_CHARS: UInt32 = 12
MD_ERROR_SUB404_URL_TOO_LONG: UInt32 = 14
MD_ERROR_SUB404_QUERY_STRING_TOO_LONG: UInt32 = 15
MD_ERROR_SUB404_STATICFILE_DAV: UInt32 = 16
MD_ERROR_SUB404_PRECONDITIONED_HANDLER: UInt32 = 17
MD_ERROR_SUB404_QUERY_STRING_SEQUENCE_DENIED: UInt32 = 18
MD_ERROR_SUB404_DENIED_BY_FILTERING_RULE: UInt32 = 19
MD_ERROR_SUB404_TOO_MANY_URL_SEGMENTS: UInt32 = 20
MD_ERROR_SUB413_CONTENT_LENGTH_TOO_LARGE: UInt32 = 1
MD_ERROR_SUB423_LOCK_TOKEN_SUBMITTED: UInt32 = 1
MD_ERROR_SUB423_NO_CONFLICTING_LOCK: UInt32 = 2
MD_ERROR_SUB500_UNC_ACCESS: UInt32 = 16
MD_ERROR_SUB500_URLAUTH_NO_STORE: UInt32 = 17
MD_ERROR_SUB500_URLAUTH_STORE_ERROR: UInt32 = 18
MD_ERROR_SUB500_BAD_METADATA: UInt32 = 19
MD_ERROR_SUB500_URLAUTH_NO_SCOPE: UInt32 = 20
MD_ERROR_SUB500_HANDLERS_MODULE: UInt32 = 21
MD_ERROR_SUB500_ASPNET_MODULES: UInt32 = 22
MD_ERROR_SUB500_ASPNET_HANDLERS: UInt32 = 23
MD_ERROR_SUB500_ASPNET_IMPERSONATION: UInt32 = 24
MD_ERROR_SUB502_TIMEOUT: UInt32 = 1
MD_ERROR_SUB502_PREMATURE_EXIT: UInt32 = 2
MD_ERROR_SUB502_ARR_CONNECTION_ERROR: UInt32 = 3
MD_ERROR_SUB502_ARR_NO_SERVER: UInt32 = 4
MD_ERROR_SUB503_CPU_LIMIT: UInt32 = 1
MD_ERROR_SUB503_APP_CONCURRENT: UInt32 = 2
MD_ERROR_SUB503_ASPNET_QUEUE_FULL: UInt32 = 3
MD_ERROR_SUB503_FASTCGI_QUEUE_FULL: UInt32 = 4
MD_ERROR_SUB503_CONNECTION_LIMIT: UInt32 = 5
MD_ACR_READ: UInt32 = 1
MD_ACR_WRITE: UInt32 = 2
MD_ACR_RESTRICTED_WRITE: UInt32 = 32
MD_ACR_UNSECURE_PROPS_READ: UInt32 = 128
MD_ACR_ENUM_KEYS: UInt32 = 8
MD_ACR_WRITE_DAC: UInt32 = 262144
MD_USER_ISOLATION_NONE: UInt32 = 0
MD_USER_ISOLATION_BASIC: UInt32 = 1
MD_USER_ISOLATION_AD: UInt32 = 2
MD_USER_ISOLATION_LAST: UInt32 = 2
IIS_CLASS_COMPUTER: String = 'IIsComputer'
IIS_CLASS_WEB_SERVICE: String = 'IIsWebService'
IIS_CLASS_WEB_SERVER: String = 'IIsWebServer'
IIS_CLASS_WEB_INFO: String = 'IIsWebInfo'
IIS_CLASS_WEB_DIR: String = 'IIsWebDirectory'
IIS_CLASS_WEB_VDIR: String = 'IIsWebVirtualDir'
IIS_CLASS_WEB_FILE: String = 'IIsWebFile'
IIS_CLASS_FTP_SERVICE: String = 'IIsFtpService'
IIS_CLASS_FTP_SERVER: String = 'IIsFtpServer'
IIS_CLASS_FTP_INFO: String = 'IIsFtpInfo'
IIS_CLASS_FTP_VDIR: String = 'IIsFtpVirtualDir'
IIS_CLASS_FILTERS: String = 'IIsFilters'
IIS_CLASS_FILTER: String = 'IIsFilter'
IIS_CLASS_LOG_MODULES: String = 'IIsLogModules'
IIS_CLASS_LOG_MODULE: String = 'IIsLogModule'
IIS_CLASS_MIMEMAP: String = 'IIsMimeMap'
IIS_CLASS_CERTMAPPER: String = 'IIsCertMapper'
IIS_CLASS_COMPRESS_SCHEMES: String = 'IIsCompressionSchemes'
IIS_CLASS_COMPRESS_SCHEME: String = 'IIsCompressionScheme'
IIS_CLASS_COMPUTER_W: String = 'IIsComputer'
IIS_CLASS_WEB_SERVICE_W: String = 'IIsWebService'
IIS_CLASS_WEB_SERVER_W: String = 'IIsWebServer'
IIS_CLASS_WEB_INFO_W: String = 'IIsWebInfo'
IIS_CLASS_WEB_DIR_W: String = 'IIsWebDirectory'
IIS_CLASS_WEB_VDIR_W: String = 'IIsWebVirtualDir'
IIS_CLASS_WEB_FILE_W: String = 'IIsWebFile'
IIS_CLASS_FTP_SERVICE_W: String = 'IIsFtpService'
IIS_CLASS_FTP_SERVER_W: String = 'IIsFtpServer'
IIS_CLASS_FTP_INFO_W: String = 'IIsFtpInfo'
IIS_CLASS_FTP_VDIR_W: String = 'IIsFtpVirtualDir'
IIS_CLASS_FILTERS_W: String = 'IIsFilters'
IIS_CLASS_FILTER_W: String = 'IIsFilter'
IIS_CLASS_LOG_MODULES_W: String = 'IIsLogModules'
IIS_CLASS_LOG_MODULE_W: String = 'IIsLogModule'
IIS_CLASS_MIMEMAP_W: String = 'IIsMimeMap'
IIS_CLASS_CERTMAPPER_W: String = 'IIsCertMapper'
IIS_CLASS_COMPRESS_SCHEMES_W: String = 'IIsCompressionSchemes'
IIS_CLASS_COMPRESS_SCHEME_W: String = 'IIsCompressionScheme'
CLSID_IisServiceControl: Guid = Guid('{e8fb8621-588f-11d2-9d61-00c04f79c5fe}')
LIBID_IISRSTALib: Guid = Guid('{e8fb8614-588f-11d2-9d61-00c04f79c5fe}')
IIS_WEBSOCKET: String = 'websockets'
IIS_WEBSOCKET_SERVER_VARIABLE: String = 'IIS_WEBSOCK'
LIBID_WAMREGLib: Guid = Guid('{29822aa8-f302-11d0-9953-00c04fd919c1}')
CLSID_WamAdmin: Guid = Guid('{61738644-f196-11d0-9953-00c04fd919c1}')
APPSTATUS_STOPPED: UInt32 = 0
APPSTATUS_RUNNING: UInt32 = 1
APPSTATUS_NOTDEFINED: UInt32 = 2
METADATA_MAX_NAME_LEN: UInt32 = 256
METADATA_PERMISSION_READ: UInt32 = 1
METADATA_PERMISSION_WRITE: UInt32 = 2
METADATA_NO_ATTRIBUTES: UInt32 = 0
METADATA_INHERIT: UInt32 = 1
METADATA_PARTIAL_PATH: UInt32 = 2
METADATA_SECURE: UInt32 = 4
METADATA_REFERENCE: UInt32 = 8
METADATA_VOLATILE: UInt32 = 16
METADATA_ISINHERITED: UInt32 = 32
METADATA_INSERT_PATH: UInt32 = 64
METADATA_LOCAL_MACHINE_ONLY: UInt32 = 128
METADATA_NON_SECURE_ONLY: UInt32 = 256
METADATA_DONT_EXPAND: UInt32 = 512
MD_BACKUP_OVERWRITE: UInt32 = 1
MD_BACKUP_SAVE_FIRST: UInt32 = 2
MD_BACKUP_FORCE_BACKUP: UInt32 = 4
MD_BACKUP_NEXT_VERSION: UInt32 = 4294967295
MD_BACKUP_HIGHEST_VERSION: UInt32 = 4294967294
MD_BACKUP_MAX_VERSION: UInt32 = 9999
MD_BACKUP_MAX_LEN: UInt32 = 100
MD_DEFAULT_BACKUP_LOCATION: String = 'MDBackUp'
MD_HISTORY_LATEST: UInt32 = 1
MD_EXPORT_INHERITED: UInt32 = 1
MD_EXPORT_NODE_ONLY: UInt32 = 2
MD_IMPORT_INHERITED: UInt32 = 1
MD_IMPORT_NODE_ONLY: UInt32 = 2
MD_IMPORT_MERGE: UInt32 = 4
MD_INSERT_PATH_STRINGA: String = '<%INSERT_PATH%>'
MD_INSERT_PATH_STRING: String = '<%INSERT_PATH%>'
METADATA_MASTER_ROOT_HANDLE: UInt32 = 0
MD_CHANGE_TYPE_DELETE_OBJECT: UInt32 = 1
MD_CHANGE_TYPE_ADD_OBJECT: UInt32 = 2
MD_CHANGE_TYPE_SET_DATA: UInt32 = 4
MD_CHANGE_TYPE_DELETE_DATA: UInt32 = 8
MD_CHANGE_TYPE_RENAME_OBJECT: UInt32 = 16
MD_CHANGE_TYPE_RESTORE: UInt32 = 32
MD_MAX_CHANGE_ENTRIES: UInt32 = 100
MD_ERROR_NOT_INITIALIZED: Int32 = -2146646016
MD_ERROR_DATA_NOT_FOUND: Int32 = -2146646015
MD_ERROR_INVALID_VERSION: Int32 = -2146646014
MD_WARNING_PATH_NOT_FOUND: Int32 = 837635
MD_WARNING_DUP_NAME: Int32 = 837636
MD_WARNING_INVALID_DATA: Int32 = 837637
MD_ERROR_SECURE_CHANNEL_FAILURE: Int32 = -2146646010
MD_WARNING_PATH_NOT_INSERTED: Int32 = 837639
MD_ERROR_CANNOT_REMOVE_SECURE_ATTRIBUTE: Int32 = -2146646008
MD_WARNING_SAVE_FAILED: Int32 = 837641
MD_ERROR_IISAO_INVALID_SCHEMA: Int32 = -2146646000
MD_ERROR_READ_METABASE_FILE: Int32 = -2146645991
MD_ERROR_NO_SESSION_KEY: Int32 = -2146645987
LIBID_ASPTypeLibrary: Guid = Guid('{d97a6da0-a85c-11cf-83ae-00a0c90c2bd8}')
CLSID_Request: Guid = Guid('{920c25d0-25d9-11d0-a55f-00a0c90c2091}')
CLSID_Response: Guid = Guid('{46e19ba0-25dd-11d0-a55f-00a0c90c2091}')
CLSID_Session: Guid = Guid('{509f8f20-25de-11d0-a55f-00a0c90c2091}')
CLSID_Server: Guid = Guid('{a506d160-25e0-11d0-a55f-00a0c90c2091}')
CLSID_ScriptingContext: Guid = Guid('{d97a6da0-a868-11cf-83ae-11b0c90c2bd8}')
HSE_VERSION_MAJOR: UInt32 = 8
HSE_VERSION_MINOR: UInt32 = 0
HSE_LOG_BUFFER_LEN: UInt32 = 80
HSE_MAX_EXT_DLL_NAME_LEN: UInt32 = 256
HSE_STATUS_SUCCESS: UInt32 = 1
HSE_STATUS_SUCCESS_AND_KEEP_CONN: UInt32 = 2
HSE_STATUS_PENDING: UInt32 = 3
HSE_STATUS_ERROR: UInt32 = 4
HSE_REQ_BASE: UInt32 = 0
HSE_REQ_SEND_URL_REDIRECT_RESP: UInt32 = 1
HSE_REQ_SEND_URL: UInt32 = 2
HSE_REQ_SEND_RESPONSE_HEADER: UInt32 = 3
HSE_REQ_DONE_WITH_SESSION: UInt32 = 4
HSE_REQ_END_RESERVED: UInt32 = 1000
HSE_REQ_MAP_URL_TO_PATH: UInt32 = 1001
HSE_REQ_GET_SSPI_INFO: UInt32 = 1002
HSE_APPEND_LOG_PARAMETER: UInt32 = 1003
HSE_REQ_IO_COMPLETION: UInt32 = 1005
HSE_REQ_TRANSMIT_FILE: UInt32 = 1006
HSE_REQ_REFRESH_ISAPI_ACL: UInt32 = 1007
HSE_REQ_IS_KEEP_CONN: UInt32 = 1008
HSE_REQ_ASYNC_READ_CLIENT: UInt32 = 1010
HSE_REQ_GET_IMPERSONATION_TOKEN: UInt32 = 1011
HSE_REQ_MAP_URL_TO_PATH_EX: UInt32 = 1012
HSE_REQ_ABORTIVE_CLOSE: UInt32 = 1014
HSE_REQ_GET_CERT_INFO_EX: UInt32 = 1015
HSE_REQ_SEND_RESPONSE_HEADER_EX: UInt32 = 1016
HSE_REQ_CLOSE_CONNECTION: UInt32 = 1017
HSE_REQ_IS_CONNECTED: UInt32 = 1018
HSE_REQ_MAP_UNICODE_URL_TO_PATH: UInt32 = 1023
HSE_REQ_MAP_UNICODE_URL_TO_PATH_EX: UInt32 = 1024
HSE_REQ_EXEC_UNICODE_URL: UInt32 = 1025
HSE_REQ_EXEC_URL: UInt32 = 1026
HSE_REQ_GET_EXEC_URL_STATUS: UInt32 = 1027
HSE_REQ_SEND_CUSTOM_ERROR: UInt32 = 1028
HSE_REQ_IS_IN_PROCESS: UInt32 = 1030
HSE_REQ_REPORT_UNHEALTHY: UInt32 = 1032
HSE_REQ_NORMALIZE_URL: UInt32 = 1033
HSE_REQ_VECTOR_SEND: UInt32 = 1037
HSE_REQ_GET_ANONYMOUS_TOKEN: UInt32 = 1038
HSE_REQ_GET_CACHE_INVALIDATION_CALLBACK: UInt32 = 1040
HSE_REQ_GET_UNICODE_ANONYMOUS_TOKEN: UInt32 = 1041
HSE_REQ_GET_TRACE_INFO: UInt32 = 1042
HSE_REQ_SET_FLUSH_FLAG: UInt32 = 1043
HSE_REQ_GET_TRACE_INFO_EX: UInt32 = 1044
HSE_REQ_RAISE_TRACE_EVENT: UInt32 = 1045
HSE_REQ_GET_CONFIG_OBJECT: UInt32 = 1046
HSE_REQ_GET_WORKER_PROCESS_SETTINGS: UInt32 = 1047
HSE_REQ_GET_PROTOCOL_MANAGER_CUSTOM_INTERFACE_CALLBACK: UInt32 = 1048
HSE_REQ_CANCEL_IO: UInt32 = 1049
HSE_REQ_GET_CHANNEL_BINDING_TOKEN: UInt32 = 1050
HSE_TERM_ADVISORY_UNLOAD: UInt32 = 1
HSE_TERM_MUST_UNLOAD: UInt32 = 2
HSE_IO_SYNC: UInt32 = 1
HSE_IO_ASYNC: UInt32 = 2
HSE_IO_DISCONNECT_AFTER_SEND: UInt32 = 4
HSE_IO_SEND_HEADERS: UInt32 = 8
HSE_IO_NODELAY: UInt32 = 4096
HSE_IO_FINAL_SEND: UInt32 = 16
HSE_IO_CACHE_RESPONSE: UInt32 = 32
HSE_IO_TRY_SKIP_CUSTOM_ERRORS: UInt32 = 64
HSE_URL_FLAGS_READ: UInt32 = 1
HSE_URL_FLAGS_WRITE: UInt32 = 2
HSE_URL_FLAGS_EXECUTE: UInt32 = 4
HSE_URL_FLAGS_SSL: UInt32 = 8
HSE_URL_FLAGS_DONT_CACHE: UInt32 = 16
HSE_URL_FLAGS_NEGO_CERT: UInt32 = 32
HSE_URL_FLAGS_REQUIRE_CERT: UInt32 = 64
HSE_URL_FLAGS_MAP_CERT: UInt32 = 128
HSE_URL_FLAGS_SSL128: UInt32 = 256
HSE_URL_FLAGS_SCRIPT: UInt32 = 512
HSE_URL_FLAGS_MASK: UInt32 = 1023
HSE_EXEC_URL_NO_HEADERS: UInt32 = 2
HSE_EXEC_URL_IGNORE_CURRENT_INTERCEPTOR: UInt32 = 4
HSE_EXEC_URL_IGNORE_VALIDATION_AND_RANGE: UInt32 = 16
HSE_EXEC_URL_DISABLE_CUSTOM_ERROR: UInt32 = 32
HSE_EXEC_URL_SSI_CMD: UInt32 = 64
HSE_EXEC_URL_HTTP_CACHE_ELIGIBLE: UInt32 = 128
HSE_VECTOR_ELEMENT_TYPE_MEMORY_BUFFER: UInt32 = 0
HSE_VECTOR_ELEMENT_TYPE_FILE_HANDLE: UInt32 = 1
HSE_APP_FLAG_IN_PROCESS: UInt32 = 0
HSE_APP_FLAG_ISOLATED_OOP: UInt32 = 1
HSE_APP_FLAG_POOLED_OOP: UInt32 = 2
SF_MAX_USERNAME: UInt32 = 257
SF_MAX_PASSWORD: UInt32 = 257
SF_MAX_AUTH_TYPE: UInt32 = 33
SF_MAX_FILTER_DESC_LEN: UInt32 = 257
SF_DENIED_LOGON: UInt32 = 1
SF_DENIED_RESOURCE: UInt32 = 2
SF_DENIED_FILTER: UInt32 = 4
SF_DENIED_APPLICATION: UInt32 = 8
SF_DENIED_BY_CONFIG: UInt32 = 65536
SF_NOTIFY_SECURE_PORT: UInt32 = 1
SF_NOTIFY_NONSECURE_PORT: UInt32 = 2
SF_NOTIFY_READ_RAW_DATA: UInt32 = 32768
SF_NOTIFY_PREPROC_HEADERS: UInt32 = 16384
SF_NOTIFY_AUTHENTICATION: UInt32 = 8192
SF_NOTIFY_URL_MAP: UInt32 = 4096
SF_NOTIFY_ACCESS_DENIED: UInt32 = 2048
SF_NOTIFY_SEND_RESPONSE: UInt32 = 64
SF_NOTIFY_SEND_RAW_DATA: UInt32 = 1024
SF_NOTIFY_LOG: UInt32 = 512
SF_NOTIFY_END_OF_REQUEST: UInt32 = 128
SF_NOTIFY_END_OF_NET_SESSION: UInt32 = 256
SF_NOTIFY_AUTH_COMPLETE: UInt32 = 67108864
SF_NOTIFY_ORDER_HIGH: UInt32 = 524288
SF_NOTIFY_ORDER_MEDIUM: UInt32 = 262144
SF_NOTIFY_ORDER_LOW: UInt32 = 131072
SF_NOTIFY_ORDER_DEFAULT: UInt32 = 131072
DISPID_HTTPREQUEST_BASE: UInt32 = 1
DISPID_HTTPREQUEST_OPEN: UInt32 = 1
DISPID_HTTPREQUEST_SETREQUESTHEADER: UInt32 = 2
DISPID_HTTPREQUEST_GETRESPONSEHEADER: UInt32 = 3
DISPID_HTTPREQUEST_GETALLRESPONSEHEADERS: UInt32 = 4
DISPID_HTTPREQUEST_SEND: UInt32 = 5
DISPID_HTTPREQUEST_OPTION: UInt32 = 6
DISPID_HTTPREQUEST_STATUS: UInt32 = 7
DISPID_HTTPREQUEST_STATUSTEXT: UInt32 = 8
DISPID_HTTPREQUEST_RESPONSETEXT: UInt32 = 9
DISPID_HTTPREQUEST_RESPONSEBODY: UInt32 = 10
DISPID_HTTPREQUEST_RESPONSESTREAM: UInt32 = 11
DISPID_HTTPREQUEST_ABORT: UInt32 = 12
DISPID_HTTPREQUEST_SETPROXY: UInt32 = 13
DISPID_HTTPREQUEST_SETCREDENTIALS: UInt32 = 14
DISPID_HTTPREQUEST_WAITFORRESPONSE: UInt32 = 15
DISPID_HTTPREQUEST_SETTIMEOUTS: UInt32 = 16
DISPID_HTTPREQUEST_SETCLIENTCERTIFICATE: UInt32 = 17
DISPID_HTTPREQUEST_SETAUTOLOGONPOLICY: UInt32 = 18
HTTP_TRACE_EVENT_FLAG_STATIC_DESCRIPTIVE_FIELDS: UInt32 = 1
HTTP_TRACE_LEVEL_START: UInt32 = 6
HTTP_TRACE_LEVEL_END: UInt32 = 7
GUID_IIS_ALL_TRACE_PROVIDERS: Guid = Guid('{00000000-0000-0000-0000-000000000000}')
GUID_IIS_WWW_SERVER_TRACE_PROVIDER: Guid = Guid('{3a2a4e84-4c21-4981-ae10-3fda0d9b0f83}')
GUID_IIS_WWW_SERVER_V2_TRACE_PROVIDER: Guid = Guid('{de4649c9-15e8-4fea-9d85-1cdda520c334}')
GUID_IIS_ASPNET_TRACE_PROVIDER: Guid = Guid('{aff081fe-0247-4275-9c4e-021f3dc1da35}')
GUID_IIS_ASP_TRACE_TRACE_PROVIDER: Guid = Guid('{06b94d9a-b15e-456e-a4ef-37c984a2cb4b}')
GUID_IIS_WWW_GLOBAL_TRACE_PROVIDER: Guid = Guid('{d55d3bc9-cba9-44df-827e-132d3a4596c2}')
GUID_IIS_ISAPI_TRACE_PROVIDER: Guid = Guid('{a1c2040e-8840-4c31-ba11-9871031a19ea}')
WEB_CORE_DLL_NAME: String = 'hwebcore.dll'
WEB_CORE_ACTIVATE_DLL_ENTRY: String = 'WebCoreActivate'
WEB_CORE_SHUTDOWN_DLL_ENTRY: String = 'WebCoreShutdown'
WEB_CORE_SET_METADATA_DLL_ENTRY: String = 'WebCoreSetMetadata'
@winfunctype('RpcProxy.dll')
def GetExtensionVersion(pVer: POINTER(win32more.Windows.Win32.System.Iis.HSE_VERSION_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('RpcProxy.dll')
def HttpExtensionProc(pECB: POINTER(win32more.Windows.Win32.System.Iis.EXTENSION_CONTROL_BLOCK)) -> UInt32: ...
@winfunctype('RpcProxy.dll')
def HttpFilterProc(pfc: POINTER(win32more.Windows.Win32.System.Iis.HTTP_FILTER_CONTEXT), NotificationType: UInt32, pvNotification: VoidPtr) -> UInt32: ...
@winfunctype('RpcProxy.dll')
def GetFilterVersion(pVer: POINTER(win32more.Windows.Win32.System.Iis.HTTP_FILTER_VERSION)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class AsyncIFtpAuthenticationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c24efb65-9f3e-4996-8fb1-ce166916bab5}')
    @commethod(3)
    def Begin_AuthenticateUser(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pszPassword: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_AuthenticateUser(self, ppszCanonicalUserName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pfAuthenticated: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpAuthorizationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{860dc339-07e5-4a5c-9c61-8820cea012bc}')
    @commethod(3)
    def Begin_GetUserAccessPermission(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszVirtualPath: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_GetUserAccessPermission(self, pFtpAccess: POINTER(win32more.Windows.Win32.System.Iis.FTP_ACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpHomeDirectoryProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{73f81638-6295-42bd-a2be-4a657f7c479c}')
    @commethod(3)
    def Begin_GetUserHomeDirectoryData(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_GetUserHomeDirectoryData(self, ppszHomeDirectoryData: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpLogProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00a0ae46-2498-48b2-95e6-df678ed7d49f}')
    @commethod(3)
    def Begin_Log(self, pLoggingParameters: POINTER(win32more.Windows.Win32.System.Iis.LOGGING_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_Log(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpPostprocessProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a16b2542-9694-4eb1-a564-6c2e91fdc133}')
    @commethod(3)
    def Begin_HandlePostprocess(self, pPostProcessParameters: POINTER(win32more.Windows.Win32.System.Iis.POST_PROCESS_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_HandlePostprocess(self, pFtpProcessStatus: POINTER(win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpPreprocessProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6ff5fd8f-fd8e-48b1-a3e0-bf7073db4db5}')
    @commethod(3)
    def Begin_HandlePreprocess(self, pPreProcessParameters: POINTER(win32more.Windows.Win32.System.Iis.PRE_PROCESS_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_HandlePreprocess(self, pFtpProcessStatus: POINTER(win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIFtpRoleProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3e83bf99-70ec-41ca-84b6-aca7c7a62caf}')
    @commethod(3)
    def Begin_IsUserInRole(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pszRole: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_IsUserInRole(self, pfIsInRole: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class AsyncIMSAdminBaseSinkW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a9e69613-b80d-11d0-b9b9-00a0c922e750}')
    @commethod(3)
    def Begin_SinkNotify(self, dwMDNumElements: UInt32, pcoChangeList: POINTER(win32more.Windows.Win32.System.Iis.MD_CHANGE_OBJECT_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Finish_SinkNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Begin_ShutdownNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Finish_ShutdownNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class CERT_CONTEXT_EX(Structure):
    CertContext: win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT
    cbAllocated: UInt32
    dwCertificateFlags: UInt32
class CONFIGURATION_ENTRY(Structure):
    _uuid_ = Guid('{9e04226f-e38c-419e-a448-62de3b3a8f43}')
    bstrKey: win32more.Windows.Win32.Foundation.BSTR
    bstrValue: win32more.Windows.Win32.Foundation.BSTR
class EXTENSION_CONTROL_BLOCK(Structure):
    cbSize: UInt32
    dwVersion: UInt32
    ConnID: win32more.Windows.Win32.System.Iis.HCONN
    dwHttpStatusCode: UInt32
    lpszLogData: win32more.Windows.Win32.Foundation.CHAR * 80
    lpszMethod: win32more.Windows.Win32.Foundation.PSTR
    lpszQueryString: win32more.Windows.Win32.Foundation.PSTR
    lpszPathInfo: win32more.Windows.Win32.Foundation.PSTR
    lpszPathTranslated: win32more.Windows.Win32.Foundation.PSTR
    cbTotalBytes: UInt32
    cbAvailable: UInt32
    lpbData: POINTER(Byte)
    lpszContentType: win32more.Windows.Win32.Foundation.PSTR
    GetServerVariable: win32more.Windows.Win32.System.Iis.PFN_IIS_GETSERVERVARIABLE
    WriteClient: win32more.Windows.Win32.System.Iis.PFN_IIS_WRITECLIENT
    ReadClient: win32more.Windows.Win32.System.Iis.PFN_IIS_READCLIENT
    ServerSupportFunction: win32more.Windows.Win32.System.Iis.PFN_IIS_SERVERSUPPORTFUNCTION
FTP_ACCESS = Int32
FTP_ACCESS_NONE: win32more.Windows.Win32.System.Iis.FTP_ACCESS = 0
FTP_ACCESS_READ: win32more.Windows.Win32.System.Iis.FTP_ACCESS = 1
FTP_ACCESS_WRITE: win32more.Windows.Win32.System.Iis.FTP_ACCESS = 2
FTP_ACCESS_READ_WRITE: win32more.Windows.Win32.System.Iis.FTP_ACCESS = 3
FTP_PROCESS_STATUS = Int32
FTP_PROCESS_CONTINUE: win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS = 0
FTP_PROCESS_CLOSE_SESSION: win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS = 1
FTP_PROCESS_TERMINATE_SESSION: win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS = 2
FTP_PROCESS_REJECT_COMMAND: win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS = 3
FtpProvider = Guid('{70bdc667-33b2-45f0-ac52-c3ca46f7a656}')
HCONN = VoidPtr
class HSE_CUSTOM_ERROR_INFO(Structure):
    pszStatus: win32more.Windows.Win32.Foundation.PSTR
    uHttpSubError: UInt16
    fAsync: win32more.Windows.Win32.Foundation.BOOL
class HSE_EXEC_UNICODE_URL_INFO(Structure):
    pszUrl: win32more.Windows.Win32.Foundation.PWSTR
    pszMethod: win32more.Windows.Win32.Foundation.PSTR
    pszChildHeaders: win32more.Windows.Win32.Foundation.PSTR
    pUserInfo: POINTER(win32more.Windows.Win32.System.Iis.HSE_EXEC_UNICODE_URL_USER_INFO)
    pEntity: POINTER(win32more.Windows.Win32.System.Iis.HSE_EXEC_URL_ENTITY_INFO)
    dwExecUrlFlags: UInt32
class HSE_EXEC_UNICODE_URL_USER_INFO(Structure):
    hImpersonationToken: win32more.Windows.Win32.Foundation.HANDLE
    pszCustomUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszCustomAuthType: win32more.Windows.Win32.Foundation.PSTR
class HSE_EXEC_URL_ENTITY_INFO(Structure):
    cbAvailable: UInt32
    lpbData: VoidPtr
class HSE_EXEC_URL_INFO(Structure):
    pszUrl: win32more.Windows.Win32.Foundation.PSTR
    pszMethod: win32more.Windows.Win32.Foundation.PSTR
    pszChildHeaders: win32more.Windows.Win32.Foundation.PSTR
    pUserInfo: POINTER(win32more.Windows.Win32.System.Iis.HSE_EXEC_URL_USER_INFO)
    pEntity: POINTER(win32more.Windows.Win32.System.Iis.HSE_EXEC_URL_ENTITY_INFO)
    dwExecUrlFlags: UInt32
class HSE_EXEC_URL_STATUS(Structure):
    uHttpStatusCode: UInt16
    uHttpSubStatus: UInt16
    dwWin32Error: UInt32
class HSE_EXEC_URL_USER_INFO(Structure):
    hImpersonationToken: win32more.Windows.Win32.Foundation.HANDLE
    pszCustomUserName: win32more.Windows.Win32.Foundation.PSTR
    pszCustomAuthType: win32more.Windows.Win32.Foundation.PSTR
class HSE_RESPONSE_VECTOR(Structure):
    dwFlags: UInt32
    pszStatus: win32more.Windows.Win32.Foundation.PSTR
    pszHeaders: win32more.Windows.Win32.Foundation.PSTR
    nElementCount: UInt32
    lpElementArray: POINTER(win32more.Windows.Win32.System.Iis.HSE_VECTOR_ELEMENT)
class HSE_SEND_HEADER_EX_INFO(Structure):
    pszStatus: win32more.Windows.Win32.Foundation.PSTR
    pszHeader: win32more.Windows.Win32.Foundation.PSTR
    cchStatus: UInt32
    cchHeader: UInt32
    fKeepConn: win32more.Windows.Win32.Foundation.BOOL
class HSE_TF_INFO(Structure):
    pfnHseIO: win32more.Windows.Win32.System.Iis.PFN_HSE_IO_COMPLETION
    pContext: VoidPtr
    hFile: win32more.Windows.Win32.Foundation.HANDLE
    pszStatusCode: win32more.Windows.Win32.Foundation.PSTR
    BytesToWrite: UInt32
    Offset: UInt32
    pHead: VoidPtr
    HeadLength: UInt32
    pTail: VoidPtr
    TailLength: UInt32
    dwFlags: UInt32
class HSE_TRACE_INFO(Structure):
    fTraceRequest: win32more.Windows.Win32.Foundation.BOOL
    TraceContextId: Byte * 16
    dwReserved1: UInt32
    dwReserved2: UInt32
class HSE_UNICODE_URL_MAPEX_INFO(Structure):
    lpszPath: Char * 260
    dwFlags: UInt32
    cchMatchingPath: UInt32
    cchMatchingURL: UInt32
class HSE_URL_MAPEX_INFO(Structure):
    lpszPath: win32more.Windows.Win32.Foundation.CHAR * 260
    dwFlags: UInt32
    cchMatchingPath: UInt32
    cchMatchingURL: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
class HSE_VECTOR_ELEMENT(Structure):
    ElementType: UInt32
    pvContext: VoidPtr
    cbOffset: UInt64
    cbSize: UInt64
class HSE_VERSION_INFO(Structure):
    dwExtensionVersion: UInt32
    lpszExtensionDesc: win32more.Windows.Win32.Foundation.CHAR * 256
class HTTP_FILTER_ACCESS_DENIED(Structure):
    pszURL: win32more.Windows.Win32.Foundation.PSTR
    pszPhysicalPath: win32more.Windows.Win32.Foundation.PSTR
    dwReason: UInt32
class HTTP_FILTER_AUTHENT(Structure):
    pszUser: win32more.Windows.Win32.Foundation.PSTR
    cbUserBuff: UInt32
    pszPassword: win32more.Windows.Win32.Foundation.PSTR
    cbPasswordBuff: UInt32
class HTTP_FILTER_AUTH_COMPLETE_INFO(Structure):
    GetHeader: IntPtr
    SetHeader: IntPtr
    AddHeader: IntPtr
    GetUserToken: IntPtr
    HttpStatus: UInt32
    fResetAuth: win32more.Windows.Win32.Foundation.BOOL
    dwReserved: UInt32
class HTTP_FILTER_CONTEXT(Structure):
    cbSize: UInt32
    Revision: UInt32
    ServerContext: VoidPtr
    ulReserved: UInt32
    fIsSecurePort: win32more.Windows.Win32.Foundation.BOOL
    pFilterContext: VoidPtr
    GetServerVariable: IntPtr
    AddResponseHeaders: IntPtr
    WriteClient: IntPtr
    AllocMem: IntPtr
    ServerSupportFunction: IntPtr
class HTTP_FILTER_LOG(Structure):
    pszClientHostName: win32more.Windows.Win32.Foundation.PSTR
    pszClientUserName: win32more.Windows.Win32.Foundation.PSTR
    pszServerName: win32more.Windows.Win32.Foundation.PSTR
    pszOperation: win32more.Windows.Win32.Foundation.PSTR
    pszTarget: win32more.Windows.Win32.Foundation.PSTR
    pszParameters: win32more.Windows.Win32.Foundation.PSTR
    dwHttpStatus: UInt32
    dwWin32Status: UInt32
    dwBytesSent: UInt32
    dwBytesRecvd: UInt32
    msTimeForProcessing: UInt32
class HTTP_FILTER_PREPROC_HEADERS(Structure):
    GetHeader: IntPtr
    SetHeader: IntPtr
    AddHeader: IntPtr
    HttpStatus: UInt32
    dwReserved: UInt32
class HTTP_FILTER_RAW_DATA(Structure):
    pvInData: VoidPtr
    cbInData: UInt32
    cbInBuffer: UInt32
    dwReserved: UInt32
class HTTP_FILTER_URL_MAP(Structure):
    pszURL: win32more.Windows.Win32.Foundation.PSTR
    pszPhysicalPath: win32more.Windows.Win32.Foundation.PSTR
    cbPathBuff: UInt32
class HTTP_FILTER_URL_MAP_EX(Structure):
    pszURL: win32more.Windows.Win32.Foundation.PSTR
    pszPhysicalPath: win32more.Windows.Win32.Foundation.PSTR
    cbPathBuff: UInt32
    dwFlags: UInt32
    cchMatchingPath: UInt32
    cchMatchingURL: UInt32
    pszScriptMapEntry: win32more.Windows.Win32.Foundation.PSTR
class HTTP_FILTER_VERSION(Structure):
    dwServerFilterVersion: UInt32
    dwFilterVersion: UInt32
    lpszFilterDesc: win32more.Windows.Win32.Foundation.CHAR * 257
    dwFlags: UInt32
class HTTP_TRACE_CONFIGURATION(Structure):
    pProviderGuid: POINTER(Guid)
    dwAreas: UInt32
    dwVerbosity: UInt32
    fProviderEnabled: win32more.Windows.Win32.Foundation.BOOL
class HTTP_TRACE_EVENT(Structure):
    pProviderGuid: POINTER(Guid)
    dwArea: UInt32
    pAreaGuid: POINTER(Guid)
    dwEvent: UInt32
    pszEventName: win32more.Windows.Win32.Foundation.PWSTR
    dwEventVersion: UInt32
    dwVerbosity: UInt32
    pActivityGuid: POINTER(Guid)
    pRelatedActivityGuid: POINTER(Guid)
    dwTimeStamp: UInt32
    dwFlags: UInt32
    cEventItems: UInt32
    pEventItems: POINTER(win32more.Windows.Win32.System.Iis.HTTP_TRACE_EVENT_ITEM)
class HTTP_TRACE_EVENT_ITEM(Structure):
    pszName: win32more.Windows.Win32.Foundation.PWSTR
    dwDataType: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE
    pbData: POINTER(Byte)
    cbData: UInt32
    pszDataDescription: win32more.Windows.Win32.Foundation.PWSTR
HTTP_TRACE_TYPE = Int32
HTTP_TRACE_TYPE_BYTE: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 17
HTTP_TRACE_TYPE_USHORT: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 18
HTTP_TRACE_TYPE_ULONG: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 19
HTTP_TRACE_TYPE_ULONGLONG: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 21
HTTP_TRACE_TYPE_CHAR: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 16
HTTP_TRACE_TYPE_SHORT: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 2
HTTP_TRACE_TYPE_LONG: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 3
HTTP_TRACE_TYPE_LONGLONG: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 20
HTTP_TRACE_TYPE_LPCWSTR: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 31
HTTP_TRACE_TYPE_LPCSTR: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 30
HTTP_TRACE_TYPE_LPCGUID: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 72
HTTP_TRACE_TYPE_BOOL: win32more.Windows.Win32.System.Iis.HTTP_TRACE_TYPE = 11
class IADMEXT(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{51dfe970-f6f2-11d0-b9bd-00a0c922e750}')
    @commethod(3)
    def Initialize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumDcomCLSIDs(self, pclsidDcom: POINTER(Guid), dwEnumIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Terminate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpAuthenticationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4659f95c-d5a8-4707-b2fc-6fd5794246cf}')
    @commethod(3)
    def AuthenticateUser(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pszPassword: win32more.Windows.Win32.Foundation.PWSTR, ppszCanonicalUserName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pfAuthenticated: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpAuthorizationProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a50ae7a1-a35a-42b4-a4f3-f4f7057a05d1}')
    @commethod(3)
    def GetUserAccessPermission(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszVirtualPath: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pFtpAccess: POINTER(win32more.Windows.Win32.System.Iis.FTP_ACCESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpHomeDirectoryProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0933b392-18dd-4097-8b9c-83325c35d9a6}')
    @commethod(3)
    def GetUserHomeDirectoryData(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, ppszHomeDirectoryData: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpLogProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a18a94cc-8299-4408-816c-7c3baca1a40e}')
    @commethod(3)
    def Log(self, pLoggingParameters: POINTER(win32more.Windows.Win32.System.Iis.LOGGING_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpPostprocessProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4522cbc6-16cd-49ad-8653-9a2c579e4280}')
    @commethod(3)
    def HandlePostprocess(self, pPostProcessParameters: POINTER(win32more.Windows.Win32.System.Iis.POST_PROCESS_PARAMETERS), pFtpProcessStatus: POINTER(win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpPreprocessProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a3c19b60-5a28-471a-8f93-ab30411cee82}')
    @commethod(3)
    def HandlePreprocess(self, pPreProcessParameters: POINTER(win32more.Windows.Win32.System.Iis.PRE_PROCESS_PARAMETERS), pFtpProcessStatus: POINTER(win32more.Windows.Win32.System.Iis.FTP_PROCESS_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpProviderConstruct(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4d1a3f7b-412d-447c-b199-64f967e9a2da}')
    @commethod(3)
    def Construct(self, configurationEntries: POINTER(win32more.Windows.Win32.System.Com.SAFEARRAY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IFtpRoleProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{909c850d-8ca0-4674-96b8-cc2941535725}')
    @commethod(3)
    def IsUserInRole(self, pszSessionId: win32more.Windows.Win32.Foundation.PWSTR, pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pszUserName: win32more.Windows.Win32.Foundation.PWSTR, pszRole: win32more.Windows.Win32.Foundation.PWSTR, pfIsInRole: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSAdminBase2W(ComPtr):
    extends: win32more.Windows.Win32.System.Iis.IMSAdminBaseW
    _iid_ = Guid('{8298d101-f992-43b7-8eca-5052d885b995}')
    @commethod(34)
    def BackupWithPasswd(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDVersion: UInt32, dwMDFlags: UInt32, pszPasswd: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def RestoreWithPasswd(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDVersion: UInt32, dwMDFlags: UInt32, pszPasswd: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def Export(self, pszPasswd: win32more.Windows.Win32.Foundation.PWSTR, pszFileName: win32more.Windows.Win32.Foundation.PWSTR, pszSourcePath: win32more.Windows.Win32.Foundation.PWSTR, dwMDFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def Import(self, pszPasswd: win32more.Windows.Win32.Foundation.PWSTR, pszFileName: win32more.Windows.Win32.Foundation.PWSTR, pszSourcePath: win32more.Windows.Win32.Foundation.PWSTR, pszDestPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def RestoreHistory(self, pszMDHistoryLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDMajorVersion: UInt32, dwMDMinorVersion: UInt32, dwMDFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def EnumHistory(self, pszMDHistoryLocation: win32more.Windows.Win32.Foundation.PWSTR, pdwMDMajorVersion: POINTER(UInt32), pdwMDMinorVersion: POINTER(UInt32), pftMDHistoryTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), dwMDEnumIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSAdminBase3W(ComPtr):
    extends: win32more.Windows.Win32.System.Iis.IMSAdminBase2W
    _iid_ = Guid('{f612954d-3b0b-4c56-9563-227b7be624b4}')
    @commethod(40)
    def GetChildPaths(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, cchMDBufferSize: UInt32, pszBuffer: win32more.Windows.Win32.Foundation.PWSTR, pcchMDRequiredBufferSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSAdminBaseSinkW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a9e69612-b80d-11d0-b9b9-00a0c922e750}')
    @commethod(3)
    def SinkNotify(self, dwMDNumElements: UInt32, pcoChangeList: POINTER(win32more.Windows.Win32.System.Iis.MD_CHANGE_OBJECT_W)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ShutdownNotify(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSAdminBaseW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{70b51430-b6ca-11d0-b9b9-00a0c922e750}')
    @commethod(3)
    def AddKey(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DeleteKey(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeleteChildKeys(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumKeys(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pszMDName: win32more.Windows.Win32.Foundation.PWSTR, dwMDEnumObjectIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CopyKey(self, hMDSourceHandle: UInt32, pszMDSourcePath: win32more.Windows.Win32.Foundation.PWSTR, hMDDestHandle: UInt32, pszMDDestPath: win32more.Windows.Win32.Foundation.PWSTR, bMDOverwriteFlag: win32more.Windows.Win32.Foundation.BOOL, bMDCopyFlag: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RenameKey(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pszMDNewName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pmdrMDData: POINTER(win32more.Windows.Win32.System.Iis.METADATA_RECORD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pmdrMDData: POINTER(win32more.Windows.Win32.System.Iis.METADATA_RECORD), pdwMDRequiredDataLen: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def DeleteData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDIdentifier: UInt32, dwMDDataType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def EnumData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pmdrMDData: POINTER(win32more.Windows.Win32.System.Iis.METADATA_RECORD), dwMDEnumDataIndex: UInt32, pdwMDRequiredDataLen: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetAllData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDAttributes: UInt32, dwMDUserType: UInt32, dwMDDataType: UInt32, pdwMDNumDataEntries: POINTER(UInt32), pdwMDDataSetNumber: POINTER(UInt32), dwMDBufferSize: UInt32, pbMDBuffer: POINTER(Byte), pdwMDRequiredBufferSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def DeleteAllData(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDUserType: UInt32, dwMDDataType: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CopyData(self, hMDSourceHandle: UInt32, pszMDSourcePath: win32more.Windows.Win32.Foundation.PWSTR, hMDDestHandle: UInt32, pszMDDestPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDAttributes: UInt32, dwMDUserType: UInt32, dwMDDataType: UInt32, bMDCopyFlag: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetDataPaths(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDIdentifier: UInt32, dwMDDataType: UInt32, dwMDBufferSize: UInt32, pszBuffer: win32more.Windows.Win32.Foundation.PWSTR, pdwMDRequiredBufferSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def OpenKey(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, dwMDAccessRequested: UInt32, dwMDTimeOut: UInt32, phMDNewHandle: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CloseKey(self, hMDHandle: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def ChangePermissions(self, hMDHandle: UInt32, dwMDTimeOut: UInt32, dwMDAccessRequested: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SaveData(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetHandleInfo(self, hMDHandle: UInt32, pmdhiInfo: POINTER(win32more.Windows.Win32.System.Iis.METADATA_HANDLE_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetSystemChangeNumber(self, pdwSystemChangeNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def GetDataSetNumber(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pdwMDDataSetNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetLastChangeTime(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pftMDLastChangeTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), bLocalTime: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetLastChangeTime(self, hMDHandle: UInt32, pszMDPath: win32more.Windows.Win32.Foundation.PWSTR, pftMDLastChangeTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), bLocalTime: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def KeyExchangePhase1(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def KeyExchangePhase2(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def Backup(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDVersion: UInt32, dwMDFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def Restore(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDVersion: UInt32, dwMDFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def EnumBackups(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, pdwMDVersion: POINTER(UInt32), pftMDBackupTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), dwMDEnumIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def DeleteBackup(self, pszMDBackupLocation: win32more.Windows.Win32.Foundation.PWSTR, dwMDVersion: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def UnmarshalInterface(self, piadmbwInterface: POINTER(win32more.Windows.Win32.System.Iis.IMSAdminBaseW)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetServerGuid(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSImpExpHelpW(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{29ff67ff-8050-480f-9f30-cc41635f2f9d}')
    @commethod(3)
    def EnumeratePathsInFile(self, pszFileName: win32more.Windows.Win32.Foundation.PWSTR, pszKeyType: win32more.Windows.Win32.Foundation.PWSTR, dwMDBufferSize: UInt32, pszBuffer: win32more.Windows.Win32.Foundation.PWSTR, pdwMDRequiredBufferSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class LOGGING_PARAMETERS(Structure):
    _uuid_ = Guid('{6c678262-fc37-406e-84e8-e9c6a5757cdc}')
    pszSessionId: win32more.Windows.Win32.Foundation.PWSTR
    pszSiteName: win32more.Windows.Win32.Foundation.PWSTR
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszHostName: win32more.Windows.Win32.Foundation.PWSTR
    pszRemoteIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwRemoteIpPort: UInt32
    pszLocalIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwLocalIpPort: UInt32
    BytesSent: UInt64
    BytesReceived: UInt64
    pszCommand: win32more.Windows.Win32.Foundation.PWSTR
    pszCommandParameters: win32more.Windows.Win32.Foundation.PWSTR
    pszFullPath: win32more.Windows.Win32.Foundation.PWSTR
    dwElapsedMilliseconds: UInt32
    FtpStatus: UInt32
    FtpSubStatus: UInt32
    hrStatus: win32more.Windows.Win32.Foundation.HRESULT
    pszInformation: win32more.Windows.Win32.Foundation.PWSTR
class MD_CHANGE_OBJECT_W(Structure):
    pszMDPath: win32more.Windows.Win32.Foundation.PWSTR
    dwMDChangeType: UInt32
    dwMDNumDataIDs: UInt32
    pdwMDDataIDs: POINTER(UInt32)
METADATATYPES = Int32
ALL_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 0
DWORD_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 1
STRING_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 2
BINARY_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 3
EXPANDSZ_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 4
MULTISZ_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 5
INVALID_END_METADATA: win32more.Windows.Win32.System.Iis.METADATATYPES = 6
class METADATA_GETALL_INTERNAL_RECORD(Structure):
    dwMDIdentifier: UInt32
    dwMDAttributes: UInt32
    dwMDUserType: UInt32
    dwMDDataType: UInt32
    dwMDDataLen: UInt32
    Anonymous: _Anonymous_e__Union
    dwMDDataTag: UInt32
    class _Anonymous_e__Union(Union):
        dwMDDataOffset: UIntPtr
        pbMDData: POINTER(Byte)
class METADATA_GETALL_RECORD(Structure):
    dwMDIdentifier: UInt32
    dwMDAttributes: UInt32
    dwMDUserType: UInt32
    dwMDDataType: UInt32
    dwMDDataLen: UInt32
    dwMDDataOffset: UInt32
    dwMDDataTag: UInt32
class METADATA_HANDLE_INFO(Structure):
    dwMDPermissions: UInt32
    dwMDSystemChangeNumber: UInt32
class METADATA_RECORD(Structure):
    dwMDIdentifier: UInt32
    dwMDAttributes: UInt32
    dwMDUserType: UInt32
    dwMDDataType: UInt32
    dwMDDataLen: UInt32
    pbMDData: POINTER(Byte)
    dwMDDataTag: UInt32
@winfunctype_pointer
def PFN_GETEXTENSIONVERSION(pVer: POINTER(win32more.Windows.Win32.System.Iis.HSE_VERSION_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_HSE_CACHE_INVALIDATION_CALLBACK(pszUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_HSE_GET_PROTOCOL_MANAGER_CUSTOM_INTERFACE_CALLBACK(pszProtocolManagerDll: win32more.Windows.Win32.Foundation.PWSTR, pszProtocolManagerDllInitFunction: win32more.Windows.Win32.Foundation.PWSTR, dwCustomInterfaceId: UInt32, ppCustomInterface: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_HSE_IO_COMPLETION(pECB: POINTER(win32more.Windows.Win32.System.Iis.EXTENSION_CONTROL_BLOCK), pContext: VoidPtr, cbIO: UInt32, dwError: UInt32) -> Void: ...
@winfunctype_pointer
def PFN_HTTPEXTENSIONPROC(pECB: POINTER(win32more.Windows.Win32.System.Iis.EXTENSION_CONTROL_BLOCK)) -> UInt32: ...
@winfunctype_pointer
def PFN_IIS_GETSERVERVARIABLE(param0: win32more.Windows.Win32.System.Iis.HCONN, param1: win32more.Windows.Win32.Foundation.PSTR, param2: VoidPtr, param3: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_IIS_READCLIENT(param0: win32more.Windows.Win32.System.Iis.HCONN, param1: VoidPtr, param2: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_IIS_SERVERSUPPORTFUNCTION(param0: win32more.Windows.Win32.System.Iis.HCONN, param1: UInt32, param2: VoidPtr, param3: POINTER(UInt32), param4: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_IIS_WRITECLIENT(param0: win32more.Windows.Win32.System.Iis.HCONN, param1: VoidPtr, param2: POINTER(UInt32), param3: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_TERMINATEEXTENSION(dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_WEB_CORE_ACTIVATE(pszAppHostConfigFile: win32more.Windows.Win32.Foundation.PWSTR, pszRootWebConfigFile: win32more.Windows.Win32.Foundation.PWSTR, pszInstanceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_WEB_CORE_SET_METADATA_DLL_ENTRY(pszMetadataType: win32more.Windows.Win32.Foundation.PWSTR, pszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_WEB_CORE_SHUTDOWN(fImmediate: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class POST_PROCESS_PARAMETERS(Structure):
    _uuid_ = Guid('{53337595-9165-4a8b-a202-7d5dbf7e4b8b}')
    pszSessionId: win32more.Windows.Win32.Foundation.PWSTR
    pszSiteName: win32more.Windows.Win32.Foundation.PWSTR
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszHostName: win32more.Windows.Win32.Foundation.PWSTR
    pszRemoteIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwRemoteIpPort: UInt32
    pszLocalIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwLocalIpPort: UInt32
    BytesSent: UInt64
    BytesReceived: UInt64
    pszCommand: win32more.Windows.Win32.Foundation.PWSTR
    pszCommandParameters: win32more.Windows.Win32.Foundation.PWSTR
    pszFullPath: win32more.Windows.Win32.Foundation.PWSTR
    pszPhysicalPath: win32more.Windows.Win32.Foundation.PWSTR
    FtpStatus: UInt32
    FtpSubStatus: UInt32
    hrStatus: win32more.Windows.Win32.Foundation.HRESULT
    SessionStartTime: win32more.Windows.Win32.Foundation.FILETIME
    BytesSentPerSession: UInt64
    BytesReceivedPerSession: UInt64
class PRE_PROCESS_PARAMETERS(Structure):
    _uuid_ = Guid('{07c3d591-cead-4702-abab-a70886af38a3}')
    pszSessionId: win32more.Windows.Win32.Foundation.PWSTR
    pszSiteName: win32more.Windows.Win32.Foundation.PWSTR
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszHostName: win32more.Windows.Win32.Foundation.PWSTR
    pszRemoteIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwRemoteIpPort: UInt32
    pszLocalIpAddress: win32more.Windows.Win32.Foundation.PWSTR
    dwLocalIpPort: UInt32
    pszCommand: win32more.Windows.Win32.Foundation.PWSTR
    pszCommandParameters: win32more.Windows.Win32.Foundation.PWSTR
    SessionStartTime: win32more.Windows.Win32.Foundation.FILETIME
    BytesSentPerSession: UInt64
    BytesReceivedPerSession: UInt64
SF_PROPERTY_IIS = Int32
SF_PROPERTY_SSL_CTXT: win32more.Windows.Win32.System.Iis.SF_PROPERTY_IIS = 0
SF_PROPERTY_INSTANCE_NUM_ID: win32more.Windows.Win32.System.Iis.SF_PROPERTY_IIS = 1
SF_REQ_TYPE = Int32
SF_REQ_SEND_RESPONSE_HEADER: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 0
SF_REQ_ADD_HEADERS_ON_DENIAL: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 1
SF_REQ_SET_NEXT_READ_SIZE: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 2
SF_REQ_SET_PROXY_INFO: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 3
SF_REQ_GET_CONNID: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 4
SF_REQ_SET_CERTIFICATE_INFO: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 5
SF_REQ_GET_PROPERTY: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 6
SF_REQ_NORMALIZE_URL: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 7
SF_REQ_DISABLE_NOTIFICATIONS: win32more.Windows.Win32.System.Iis.SF_REQ_TYPE = 8
SF_STATUS_TYPE = Int32
SF_STATUS_REQ_FINISHED: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217728
SF_STATUS_REQ_FINISHED_KEEP_CONN: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217729
SF_STATUS_REQ_NEXT_NOTIFICATION: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217730
SF_STATUS_REQ_HANDLED_NOTIFICATION: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217731
SF_STATUS_REQ_ERROR: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217732
SF_STATUS_REQ_READ_NEXT: win32more.Windows.Win32.System.Iis.SF_STATUS_TYPE = 134217733


make_ready(__name__)
